import axios from "axios";
import { COURSE } from "../constants/action-types";

export const getAllCourseByUser = () => {
    return async (dispatch) => {
        dispatch({ type: COURSE.GET_ALL_COURSE_BY_USER_LOADING });
        await axios
            .get("/course/all-by-user-cms", {
            })
            .then((response) => {
                dispatch({
                    type: COURSE.GET_ALL_COURSE_BY_USER_LOADED,
                    payload: response.data.courses
                });
            })
            .catch((err) => {
                dispatch({
                    type: COURSE.GET_ALL_COURSE_BY_USER_ERROR,
                    payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    };
};
export const getAllQualityCourseByUser = () => {
    return async (dispatch) => {
        dispatch({ type: COURSE.GET_ALL_COURSE_BY_USER_LOADING });
        await axios
            .get("/course/quality-all-by-user-cms", {
            })
            .then((response) => {
                dispatch({
                    type: COURSE.GET_ALL_COURSE_BY_USER_LOADED,
                    payload: response.data.courses

                });
            })
            .catch((err) => {
                dispatch({
                    type: COURSE.GET_ALL_COURSE_BY_USER_ERROR,
                    payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    };
};
export const getAllDigitalTwinCourseByUser = () => {
  return async (dispatch) => {
    dispatch({ type: COURSE.GET_ALL_COURSE_BY_USER_LOADING });
    await axios
      .get("/course/digital-twin-all-by-user-cms", {})
      .then((response) => {
        dispatch({
          type: COURSE.GET_ALL_COURSE_BY_USER_LOADED,
          payload: response.data.courses,
        });
      })
      .catch((err) => {
        dispatch({
          type: COURSE.GET_ALL_COURSE_BY_USER_ERROR,
          payload: {
            message: err.response.data.error.message,
            code: err.response.data.error.code,
          },
        });
      });
  };
};
export const deleteCourseByCourseID = (courseId) => {
    return async (dispatch) => {
        dispatch({ type: COURSE.COURSE_DELETING });
        await axios
            .delete("/course/delete-course-by-id/" + courseId, {
            })
            .then((response) => {
                dispatch({
                    type: COURSE.COURSE_DELETED,
                });
            })
            .catch((err) => {
                dispatch({
                    type: COURSE.COURSE_DELETE_ERROR,
                    payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    };
};
export const getCourseDataById = (id) => {
    return async (dispatch) => {
        dispatch({ type: COURSE.GET_COURSE_BY_ID_LOADING });
        await axios
            .get("/course/all-by-user-cms/" + id, {
            })
            .then((response) => {
                dispatch({
                    type: COURSE.GET_COURSE_BY_ID_LOADED,
                    payload: response.data.course

                });
            })
            .catch((err) => {
                dispatch({
                    type: COURSE.GET_COURSE_BY_ID_ERROR,
                    payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    };
}
export const editCourseBaseData = (obj) => {
    return async (dispatch) => {
        dispatch({ type: COURSE.BASE_SAVING });
        await axios
            .post("/course/edit-course-base-data/", obj)
            .then((response) => {
                dispatch({
                    type: COURSE.BASE_SAVED,
                });
            })
            .catch((err) => {
                dispatch({
                    type: COURSE.BASE_SAVE_ERROR,
                    payload: {
                        message: err.response.data.message,
                        code: err.response.data.code,
                    },
                });
            });
    };
}
export const setActiveOrDeactiveCourse = (obj) => {
    return async (dispatch) => {
        dispatch({ type: COURSE.IS_ACTIVE_LOADING });
        await axios
          .put("/course/set-course-active-or-deactive/", obj)
          .then((response) => {
            dispatch({
              type: COURSE.IS_ACTIVE_LOADED,
            });
          })
          .catch((err) => {
            dispatch({
              type: COURSE.IS_ACTIVE_ERROR,
              payload: {
                message: err.response.data.message,
                code: err.response.data.code,
              },
            });
          });
    };
}
export const setUsersToCourse = (obj) => {
    return async (dispatch) => {
        dispatch({ type: COURSE.USER_LIST_EDIT_SAVING });
        await axios
            .post("/course/set-users-to-course/", obj)
            .then((response) => {
                dispatch({
                    type: COURSE.USER_LIST_EDIT_SAVE,
                });
            })
            .catch((err) => {
                dispatch({
                    type: COURSE.USER_LIST_EDIT_SAVE_ERROR,
                    payload: {
                        message: err.response.data.message,
                        code: err.response.data.code,
                    },
                });
            });
    };
}
export const duplicateCourse = (id) => {
    return async (dispatch) => {
        dispatch({ type: COURSE.DUPLICATE_LOADING });
        await axios
          .put("/course/duplicate-course/" + id )
          .then((response) => {
            dispatch({
              type: COURSE.DUPLICATE_LOADED,
            });
          })
          .catch((err) => {
            dispatch({
              type: COURSE.DUPLICATE_ERROR,
              payload: {
                message: err.response.data.message,
                code: err.response.data.code,
              },
            });
          });
    };
}
//PDF
export const genereatePDF = (obj) => {
    return async (dispatch) => {
        dispatch({ type: COURSE.GENERATE_PDF_LOADING });
        await axios
            .post("/files/generate-pdf/", obj)
            .then((response) => {
                dispatch({
                    type: COURSE.GENERATE_PDF_LOADED,
                    payload: response.data.pdfUrl
                });
            })
            .catch((err) => {
                dispatch({
                    type: COURSE.GENERATE_PDF_ERROR,
                    payload: {
                        message: err.response.data.message,
                        code: err.response.data.code,
                    },
                });
            });
    };
}
export const generateAllUserPDF = (obj) => {
    return async (dispatch) => {
        dispatch({ type: COURSE.GENERATE_ALL_PDF_LOADING });
        await axios
            .post("/files/generate-all-user-exam-pdf/", obj)
            .then((response) => {
                dispatch({
                    type: COURSE.GENERATE_ALL_PDF_LOADED,
                    payload: response.data.pdfUrl
                });
            })
            .catch((err) => {
                dispatch({
                    type: COURSE.GENERATE_ALL_PDF_ERROR,
                    payload: {
                        message: err.response.data.message,
                        code: err.response.data.code,
                    },
                });
            });
    };
}
export const getCourseDocumentation = (id) => {
  return async (dispatch) => {
    dispatch({ type: COURSE.GET_DOCUMENTATION_LOADING });
    await axios
      .get("/files/get-course-documentation/" + id)
      .then((response) => {
        dispatch({
          type: COURSE.GET_DOCUMENTATION_LOADED,
          payload: response.data.pdfUrl,
        });
      })
      .catch((err) => {
        dispatch({
          type: COURSE.GET_DOCUMENTATION_ERROR,
          payload: {
            message: err.response.data.message,
            code: err.response.data.code,
          },
        });
      });
  };
};
export const getCourseDocumentationData = (id) => {
  return async (dispatch) => {
    dispatch({ type: COURSE.GET_DOCUMENTATION_DATA_LOADING });
    await axios
      .get("/files/get-course-documentation-to-cms/" + id)
      .then((response) => {
        dispatch({
          type: COURSE.GET_DOCUMENTATION_DATA_LOADED,
          payload: response.data.documentation,
        });
      })
      .catch((err) => {
        dispatch({
          type: COURSE.GET_DOCUMENTATION_DATA_ERROR,
          payload: {
            message: err.response.data.message,
            code: err.response.data.code,
          },
        });
      });
  };
};
export const setDocumetation = (data) => {
  return async (dispatch) => {
    dispatch({ type: COURSE.SET_DOCUMENTATION_SAVING });
    await axios
      .put("/course/set-documetation", data)
      .then((response) => {
        dispatch({
          type: COURSE.SET_DOCUMENTATION_SAVED,
        });
      })
      .catch((err) => {
        dispatch({
          type: COURSE.SET_DOCUMENTATION_ERROR,
          payload: {
            message: err.response.data.message,
            code: err.response.data.code,
          },
        });
      });
  };
};
export const getCourseStatistics = (id) => {
  return async (dispatch) => {
    dispatch({ type: COURSE.GET_STATISTICS_LOADING });
    await axios
      .get("/statistics/get-course-exam-statistics/" + id)
      .then((response) => {
        dispatch({
          type: COURSE.GET_STATISTICS_LOADED,
          payload: response.data,
        });
      })
      .catch((err) => {
        dispatch({
          type: COURSE.GET_STATISTICS_ERROR,
          payload: {
            message: err.response.data.message,
            code: err.response.data.code,
          },
        });
      });
  };
};
