import axios from "axios";
import { FILE_MANAGER } from "../constants/action-types";

export const getCourseAllFiles = (courseId) => {
    return async (dispatch) => {
        dispatch({ type: FILE_MANAGER.GET_ALL_FILE_BY_COURSE_ID_LOADING });
        await axios
            .get("files/get-file-list-by-course-id/" + courseId, {
            })
            .then((response) => {
                dispatch({
                    type: FILE_MANAGER.GET_ALL_FILE_BY_COURSE_ID_LOADED,
                    payload: response.data

                });
            })
            .catch((err) => {
                dispatch({
                    type: FILE_MANAGER.GET_ALL_FILE_BY_COURSE_ID_ERROR,
                    payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    };
};
export const getAllFiles = (courseId) => {
    return async (dispatch) => {
        dispatch({ type: FILE_MANAGER.GET_ALL_FILE_LOADING });
        await axios
            .get("files" , {
            })
            .then((response) => {
                dispatch({
                    type: FILE_MANAGER.GET_ALL_FILE_LOADED,
                    payload: response.data

                });
            })
            .catch((err) => {
                dispatch({
                    type: FILE_MANAGER.GET_ALL_FILE_ERROR,
                    payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    };
};
export const getAllCourseByFile = (fileId) => {
    return async (dispatch) => {
        dispatch({ type: FILE_MANAGER.GET_ALL_COURSE_BY_FILE_LOADING });
        await axios
          .get("files/get-file-courses/" + fileId, {})
          .then((response) => {
            dispatch({
              type: FILE_MANAGER.GET_ALL_COURSE_BY_FILE_LOADED,
              payload: response.data,
            });
          })
          .catch((err) => {
            dispatch({
              type: FILE_MANAGER.GET_ALL_COURSE_BY_FILE_ERROR,
              payload: {
                message: err.response.data.error.message,
                code: err.response.data.error.code,
              },
            });
          });
    };
};
export const uploadFiles = (formData) => {
  return async (dispatch) => {
    dispatch({ type: FILE_MANAGER.FILE_SAVING });
    await axios
      .post("/files/upload-file", formData)
      .then((response) => {
        dispatch({
          type: FILE_MANAGER.FILE_SAVED
        });
      })
      .catch((err) => {
        dispatch({
          type: FILE_MANAGER.FILE_ERROR,
          payload: {
            message: err.response.data.message,
            code: err.response.data.code,
          },
        });
      });
  };
};
export const deleteFile = (fileId) => {
  return async (dispatch) => {
    dispatch({ type: FILE_MANAGER.DELETE_LOADING });
    await axios
      .delete("/files/delete-file-by-id/" + fileId)
      .then((response) => {
        dispatch({
          type: FILE_MANAGER.DELETE_LOADED,
        });
      })
      .catch((err) => {
        dispatch({
          type: FILE_MANAGER.DELETE_ERROR,
          payload: {
            message: err.response.data.error.message,
            code: err.response.data.error.code,
          },
        });
      });
  };
};