import axios from "axios";
import { USER, REGISTRATION } from "../constants/action-types";

export const getAllUser = () => {
    return async (dispatch) => {
        dispatch({ type: USER.GET_ALL_USER_LOADING });
        await axios
            .get("/users/all-user", {
            })
            .then((response) => {
                dispatch({
                    type: USER.GET_ALL_USER_LOADED,
                    payload: response.data.users

                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.GET_ALL_USER_ERROR,
                    payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    };
};

export const getUserById = (userId) => {
    return async (dispatch) => {
        dispatch({ type: USER.USER_DATA_LOADING });
        await axios
            .get("/users/user-by-id", {
                params: {
                    userId: userId
                }
            })
            .then((response) => {
                dispatch({
                    type: USER.USER_DATA_LOADED,
                    payload: response.data

                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.USER_DATA_ERROR,
                    payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    };
};
export const getAllUserWithoutAdmin = () => {
    return async (dispatch) => {
        dispatch({ type: USER.GET_ALL_USER_WITHOUT_ADMIN_LOADING });
        await axios
            .get("/users/get-all-without-admin", {})
            .then((response) => {
                dispatch({
                    type: USER.GET_ALL_USER_WITHOUT_ADMIN_LOADED,
                    payload: response.data

                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.GET_ALL_USER_WITHOUT_ADMIN_ERROR,
                    payload: { message: err, code: err },
                });
            });
    };
};
export const getAllPlayer = () => {
    return async (dispatch) => {
        dispatch({ type: USER.GET_ALL_PLAYER_LOADING });
        await axios
            .get("/users/get-all-player", {})
            .then((response) => {
                dispatch({
                    type: USER.GET_ALL_PLAYER_LOADED,
                    payload: response.data

                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.GET_ALL_PLAYER_ERROR,
                    payload: { message: err, code: err },
                });
            });
    };
};
export const getAllAdmin = () => {
    return async (dispatch) => {
        dispatch({ type: USER.GET_ALL_ADMIN_LOADING });
        await axios
            .get("/users/get-all-admin", {})
            .then((response) => {
                dispatch({
                    type: USER.GET_ALL_ADMIN_LOADED,
                    payload: response.data

                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.GET_ALL_ADMIN_ERROR,
                    payload: { message: err, code: err },
                });
            });
    };
};
export const getAllMaintainer = () => {
    return async (dispatch) => {
        dispatch({ type: USER.GET_ALL_MAINTAINER_LOADING });
        await axios
            .get("/users/get-all-maintainer", {})
            .then((response) => {
                dispatch({
                    type: USER.GET_ALL_MAINTAINER_LOADED,
                    payload: response.data

                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.GET_ALL_MAINTAINER_ERROR,
                    payload: { message: err, code: err },
                });
            });
    };
};
export const getAllCourseUsers = (courseId) => {
    return async (dispatch) => {
        dispatch({ type: USER.GET_ALL_COURSE_USERS_LOADING });
        await axios
            .get("/users/users-by-course/" + courseId, {})
            .then((response) => {
                dispatch({
                    type: USER.GET_ALL_COURSE_USERS_LOADED,
                    payload: response.data
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.GET_ALL_COURSE_USERS_ERROR,
                    payload: { message: err, code: err },
                });
            });
    };
};
export const getAllCourseUsersExam = (courseId) => {
    return async (dispatch) => {
        dispatch({ type: USER.GET_ALL_COURSE_USERS_EXAM_LOADING });
        await axios
            .get("/users/users-by-course-exam/" + courseId, {})
            .then((response) => {
                dispatch({
                    type: USER.GET_ALL_COURSE_USERS_EXAM_LOADED,
                    payload: response.data
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.GET_ALL_COURSE_USERS_ERROR,
                    payload: { message: err, code: err },
                });
            });
    };
};
export const deleteUserById = (id) => {
    return async (dispatch) => {
        dispatch({ type: USER.USER_DELETE_SENDING });
        await axios
            .delete("/users/delete-user-by-id/" + id)
            .then((response) => {
                dispatch({
                    type: USER.USER_DELETE_SENDED
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.USER_DELETE_ERROR,
                    payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    }
};
export const registerUser = (saveObj) => {
    return async (dispatch) => {
        dispatch({ type: REGISTRATION.REGISTRATION_LOADING });
        await axios
            .post("/users/registration-from-cms", saveObj)
            .then((response) => {
                dispatch({
                    type: REGISTRATION.REGISTRATION_LOADED,
                    payload: { user: response.data.user },
                });
            })
            .catch((err) => {
                dispatch({
                    type: REGISTRATION.REGISTRATION_ERROR,
                    payload: { message: err.response.data.messega, code: err.response.data.code },
                });
            });
    };
};
export const modifyUser = (saveObj) => {
    return async (dispatch) => {
        dispatch({ type: USER.MODIFY_USER_SENDING });
        await axios
            .post("/users/modify-user", saveObj)
            .then((response) => {
                dispatch({
                    type: USER.MODIFY_USER_SENDED,
                    payload: { user: response.data },
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.MODIFY_USER_ERROR,
                    payload: { message: err.response.data.messega, code: err.response.data.code },
                });
            });
    };
};
export const modifyAdminAndTrainer = (saveObj) => {
    return async (dispatch) => {
        dispatch({ type: USER.MODIFY_ADMIN_SENDING });
        await axios
            .post("/users/modify-admin-and-trainer", saveObj)
            .then((response) => {
                dispatch({
                    type: USER.MODIFY_ADMIN_SENDED,
                    payload: { user: response.data },
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.MODIFY_ADMIN_ERROR,
                    payload: { message: err.response.data.messega, code: err.response.data.code },
                });
            });
    };
};

export const deleteUsersByIds = (ids) => {
    return async (dispatch) => {
        dispatch({ type: USER.DELETE_USERS_SENDING });
        await axios
            .post("users/delete-users-by-ids",
                ids
            )
            .then((response) => {
                dispatch({
                    type: USER.DELETE_USERS_SENDED
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.DELETE_USERS_ERROR,
                    // payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    }
};
export const updateLoggedInUserProfile = (userProfile) => {
    return async (dispatch) => {
        dispatch({ type: USER.UPDATE_LOGGED_IN_USER_LOADING });
        await axios
            .post("users/edit-user-from-cms",
                userProfile
            )
            .then((response) => {
                dispatch({
                    type: USER.UPDATE_LOGGED_IN_USER_LOADED
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.UPDATE_LOGGED_IN_USER_ERROR,
                    // payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    }

};
export const deactivateAndActivateUsersById = (userId) => {
    return async (dispatch) => {
        dispatch({ type: USER.ACTIVE_OR_DEACTIVE_LOADING });
        await axios
            .post("users/activate-deactivate-users-by-ids/" + userId, {}
            )
            .then((response) => {
                dispatch({
                    type: USER.ACTIVE_OR_DEACTIVE_LOADED
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.ACTIVE_OR_DEACTIVE_ERROR,
                    // payload: { message: err.response.data.error.message, code: err.response.data.error.code },
                });
            });
    }
};
export const getNewCode = () => {
    return async (dispatch) => {
        dispatch({ type: USER.GET_NEW_USER_CODE_LOADING });
        await axios
            .get("/users/new-code", {})
            .then((response) => {
                dispatch({
                    type: USER.GET_NEW_USER_CODE_LOADED,
                    payload: response.data
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.GET_NEW_USER_CODE_ERROR,
                    payload: { message: err, code: err },
                });
            });
    };
};
export const addNewUser = (saveObj) => {
    return async (dispatch) => {
        dispatch({ type: USER.ADD_USER_SENDING });
        await axios
            .post("/users/new-user", saveObj)
            .then((response) => {
                dispatch({
                    type: USER.ADD_USER_SENDED,
                    payload: { user: response.data },
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.ADD_USER_ERROR,
                    payload: { message: err.response.data.messega, code: err.response.data.code },
                });
            });
    };
};
export const editUser = (saveObj) => {
    return async (dispatch) => {
        dispatch({ type: USER.ADD_USER_SENDING });
        await axios
            .post("/users/edit-user", saveObj)
            .then((response) => {
                dispatch({
                    type: USER.ADD_USER_SENDED,
                    payload: { user: response.data },
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.ADD_USER_ERROR,
                    payload: { message: err.response.data.messega, code: err.response.data.code },
                });
            });
    };
};
export const addNewAdminOrTrainer = (saveObj) => {
    return async (dispatch) => {
        dispatch({ type: USER.ADD_ADMIN_OR_TRAINER_SENDING });
        await axios
            .post("/users/new-admin-or-trainer", saveObj)
            .then((response) => {
                dispatch({
                    type: USER.ADD_ADMIN_OR_TRAINER_SENDED,
                    payload: { user: response.data },
                });
            })
            .catch((err) => {
                dispatch({
                    type: USER.ADD_ADMIN_OR_TRAINER_ERROR,
                    payload: { message: err.response.data.messega, code: err.response.data.code },
                });
            });
    };
};

export const getAllUserCourseData = (userId) => {
    return async (dispatch) => {
        dispatch({ type: USER.USER_COURSE_LOADING });
        await axios
          .get("/users/user-course/" + userId)
          .then((response) => {
            dispatch({
              type: USER.USER_COURSE_LOADED,
              payload: { user: response.data },
            });
          })
          .catch((err) => {
            dispatch({
              type: USER.USER_COURSE_ERROR,
              payload: {
                message: err.response.data.messega,
                code: err.response.data.code,
              },
            });
          });
    };
};

