import { Button, Col, Input, Mentions, notification, Row } from "antd";
import React, { Component } from "react";
import { withTranslation } from "react-i18next";
import { connect } from "react-redux";
import { editCourseBaseData } from "../../actions/course";
import { Select } from "antd";

const { Option } = Select;

const mapDispatchToProps = (dispatch) => {
  return {
    editCourseBaseData: (saveObj) => dispatch(editCourseBaseData(saveObj)),
  };
};
class ConnectedCourseBaseDataPage extends Component {
  state = {
    name: "",
    description: "",
    createdDate: "",
    studentNumber: 100,
    isEditable: false,
    selectedLanguage: {},
    courseStatusId: 1,
  };

  componentDidMount = () => {
    console.log(this.props.courseData);
    this.setState({
      name: this.props.courseData.name,
      description: this.props.courseData.description,
      selectedLanguage: this.props.languages.find(
        (item) => item.id === this.props.courseData.language.id
      ),
      courseStatusId: this.props.courseData.courseStatus.id,
      createdDate: new Date(
        this.props.courseData.created * 1000
      ).toLocaleDateString(),
      modifiedDate: new Date(
        this.props.courseData.modified * 1000
      ).toLocaleDateString(),
      studentNumber: this.props.couseStudentNumber,
      successfullExamStudentNumber: this.props.successfullExamStudentNumber,
      notSuccessfullExamStudentNumber: this.props
        .notSuccessfullExamStudentNumber,
    });
  };
  setEditTrue = () => {
    this.setState({ isEditable: true });
  };
  setEditFalse = () => {
    this.setState({
      isEditable: false,
      name: this.props.courseData.name,
      description: this.props.courseData.description,
    });
  };
  selectLanguage = (value) => {
    const selectedLanguage = this.props.languages.find(
      (item) => item.id === value
    );
    this.setState({ selectedLanguage: selectedLanguage });
  };
  selectStatus = (value) => {
    this.setState({ courseStatusId: value });
  };

  changeName = (event) => {
    const actvalue = event.target.value;
    this.setState({ name: actvalue });
  };
  changeDescription = (event) => {
    const actvalue = event;
    this.setState({ description: actvalue });
  };
  saveChanges = async () => {
    const saveObj = {
      courseId: this.props.courseData.id,
      name: this.state.name,
      description:
        this.state.description && this.state.description.trim() !== ""
          ? this.state.description
          : undefined,
      languageId: this.state.selectedLanguage.id,
      statusId: this.state.courseStatusId,
    };
    await this.props.editCourseBaseData(saveObj);
    if (
      this.props.baseSavingStatus &&
      this.props.baseSavingStatus === "saved"
    ) {
           notification["success"]({
             message: this.props.t("COURSE_SAVE_SUCCES_TITLE"),
             description: this.props.t("COURSE_SAVE_SUCCES_DESCRIPTION"),
             onClick: () => {},
           });
    }
    if (
      this.props.baseSavingStatus &&
      this.props.baseSavingStatus === "error"
    ) {
      notification["error"]({
        message: this.props.t("COURSE_SAVE_ERROR_TITLE"),
        description: this.props.t("COURSE_SAVE_ERROR_DESCRIPTION"),
        onClick: () => {},
      });

    }
    this.setState({ isEditable: false });
  };
  render() {
    return (
      <div>
        <Row gutter={24} align="middle" justify="end">
          {!this.state.isEditable && (
            <Col>
              <Button type="primary" onClick={this.setEditTrue}>
                {this.props.t("COURSE_BADE_DATA_PAGE_BUTTON_EDIT")}
              </Button>
            </Col>
          )}
          {this.state.isEditable && (
            <Col>
              <Button type="primary" onClick={this.saveChanges}>
                {this.props.t("COURSE_BADE_DATA_PAGE_BUTTON_SAVE")}
              </Button>
              <Button style={{ marginLeft: 20 }} onClick={this.setEditFalse}>
                {this.props.t("COURSE_BADE_DATA_PAGE_BUTTON_CANCEL")}
              </Button>
            </Col>
          )}
        </Row>
        <Row gutter={24}>
          <Col span={12}>
            <Col span={24}>
              <h3>
                {this.props.t("COURSE_BASE_DATA_PAGE_MENU_COURSE_LANGUAGE")}:
              </h3>

              <Select
                value={this.state.selectedLanguage.id}
                style={{ width: "100%" }}
                onChange={this.selectLanguage}
                disabled={!this.state.isEditable}
              >
                {this.props.languages &&
                  this.props.languages.map((item) => {
                    return (
                      <Option value={item.id}>
                        <img
                          src={process.env.REACT_APP_API_URL + item.flagURL}
                          alt={item.name}
                          className="logo-icon"
                          style={{ maxHeight: "1em", paddingRight: "1em" }}
                        />
                        {item.name}
                      </Option>
                    );
                  })}
              </Select>
            </Col>
            <Col span={24}>
              <h3>
                {this.props.t("COURSE_BASE_DATA_PAGE_MENU_COURSE_STATUS")}:
              </h3>

              <Select
                value={this.state.courseStatusId}
                style={{ width: "100%" }}
                onChange={this.selectStatus}
                disabled={!this.state.isEditable}
              >
                <Option value={1}>Szerkeszthető</Option>
                <Option value={2}>Publikált</Option>
                <Option value={3}>Inaktív</Option>
              </Select>
            </Col>
            <Col span={24}>
              <h3>{this.props.t("COURSE_BASE_DATA_PAGE_MENU_COURSE_NAME")}:</h3>
              <Input
                onChange={this.changeName}
                disabled={!this.state.isEditable}
                value={this.state.name}
              ></Input>
            </Col>
            <Col span={24}>
              <h3>
                {this.props.t("COURSE_BASE_DATA_PAGE_MENU_COURSE_DESCRIPTION")}:
              </h3>
              <Mentions
                onChange={this.changeDescription}
                disabled={!this.state.isEditable}
                value={this.state.description}
                style={{ width: "100%", height: "100%" }}
                rows={6}
                //onChange={this.changeComment}
              ></Mentions>
            </Col>
            <Col span={24}>
              <h3>
                {this.props.t("COURSE_BASE_DATA_PAGE_MENU_COURSE_CREATED")}:
              </h3>
              <Input disabled={true} value={this.state.createdDate}></Input>
            </Col>
            <Col span={24}>
              <h3>
                {this.props.t("COURSE_BASE_DATA_PAGE_MENU_COURSE_EDIT_TIME")}:
              </h3>
              <Input disabled={true} value={this.state.modifiedDate}></Input>
            </Col>
            <Col span={24}>
              <h3>
                {this.props.t(
                  "COURSE_BASE_DATA_PAGE_MENU_COURSE_STUDENT_NUMBER"
                )}
                :
              </h3>
              <Input value={this.state.studentNumber} disabled={true}></Input>
            </Col>
            <Col span={24}>
              <h3>
                {this.props.t(
                  "COURSE_BASE_DATA_PAGE_MENU_COURSE_FINISHED_STUDENT_NUMBER"
                )}
                :
              </h3>
              <Input
                value={this.state.successfullExamStudentNumber}
                disabled={true}
              ></Input>
            </Col>
            <Col span={24}>
              <h3>
                {this.props.t(
                  "COURSE_BASE_DATA_PAGE_MENU_COURSE_NOT_FINISHED_STUDENT_NUMBER"
                )}
                :
              </h3>
              <Input
                value={this.state.notSuccessfullExamStudentNumber}
                disabled={true}
              ></Input>
            </Col>
          </Col>
        </Row>
      </div>
    );
  }
}
const mapStateToProps = (state) => ({
  languages: state.languageReducer.languages,
  baseSavingStatus: state.courseReducer.baseSavingStatus,
});
const CourseBaseDataPage = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedCourseBaseDataPage)
);
export default CourseBaseDataPage;
