import { Button, Col, Row, Tabs } from "antd";
import React, { Component } from "react";
import { withTranslation } from "react-i18next";
import { connect } from "react-redux";
import { getCourseDataById } from "../../actions/course";
import CourseBaseDataPage from "./course-base-data-page";
import CourseExamineesPage from "./course-examinees-page";
import CourseFilePage from "./course-file-page";
import CourseStatisticsPage from "./course-satatistics-page";
import CourseUserPage from "./course-user-page";
import Cookies from "universal-cookie";
import DocumentationPage from "./documentation-page";

const { TabPane } = Tabs;
const mapDispatchToProps = (dispatch) => {
  return {
    getCourseDataById: (courseId) => dispatch(getCourseDataById(courseId)),
  };
};

class ConnectedCourseDataSheet extends Component {
  state = {
    actKey: "1",
    courseData: undefined,
    couseStudentNumber: 100,
    successfullExamStudentNumber: 100,
    notSuccessfullExamStudentNumber: 100,
    courseActive: false,
    intervalId: null,
  };

  componentDidMount = async () => {
    await this.props.getCourseDataById(this.props.courseId);
    const i = setInterval(() => {
      const webGLStatus = this.checkCookies();
      if (this.state.courseActive !== webGLStatus) {
        this.setState({ courseActive: webGLStatus });
      }
    }, 1000);
    this.setState({ intervalId: i });
    if (this.props.course) {
      this.setState({
        courseData: this.props.course.course,
        couseStudentNumber: this.props.course.studentNumber,
        successfullExamStudentNumber:
          this.props.course.successfullExamStudentNumber,
        notSuccessfullExamStudentNumber:
          this.props.course.notSuccessfullExamStudentNumber,
      });
      this.props.setCourse(this.props.course);
    }
  };
  componentWillUnmount = () => {
    clearInterval(this.state.intervalId);
  };

  callback = (key) => {
    this.setState({ actKey: key });
  };
  checkCookies = () => {
    const cookies = new Cookies();
    const a = cookies.get("isEditorOpen");
    console.log(a);
    if (a === "false") {
      return false;
    } else {
      return true;
    }
  };

  openNewCourseInNewTab = async () => {
    window.open("/unity");
  };
  render() {
    return (
      <div>
        <Row gutter={[24, 24]}>
          <Col>
            <Button
              disabled={!this.state.courseActive}
              type="primary"
              onClick={this.openNewCourseInNewTab}
            >
              {this.props.t("COURSE_DATA_SHEET_TAB_NAME_6")}
            </Button>
          </Col>
          <Col span={24}>
            {this.state.courseData && (
              <Tabs
                defaultActiveKey="1"
                tabPosition="left"
                onChange={this.callback}
              >
                <TabPane
                  tab={this.props.t("COURSE_DATA_SHEET_TAB_NAME_1")}
                  key="1"
                >
                  <CourseBaseDataPage
                    courseData={this.state.courseData}
                    couseStudentNumber={this.state.couseStudentNumber}
                    successfullExamStudentNumber={
                      this.state.successfullExamStudentNumber
                    }
                    notSuccessfullExamStudentNumber={
                      this.state.notSuccessfullExamStudentNumber
                    }
                  />
                </TabPane>
                <TabPane
                  tab={this.props.t("COURSE_DATA_SHEET_TAB_NAME_2")}
                  key="2"
                >
                  <CourseStatisticsPage courseId={this.props.courseId} />
                </TabPane>
                <TabPane
                  destroyInactiveTabPane={true}
                  tab={this.props.t("COURSE_DATA_SHEET_TAB_NAME_3")}
                  key="3"
                >
                  {this.state.actKey === "3" && (
                    <CourseFilePage courseId={this.props.courseId} />
                  )}
                </TabPane>
                <TabPane
                  tab={this.props.t("COURSE_DATA_SHEET_TAB_NAME_4")}
                  key="4"
                >
                  <CourseUserPage
                    courseName={this.state.courseData.name}
                    courseId={this.props.courseId}
                  />
                </TabPane>
                <TabPane
                  tab={this.props.t("COURSE_DATA_SHEET_TAB_NAME_5")}
                  key="5"
                >
                  <CourseExamineesPage
                    courseName={this.state.courseData.name}
                    courseId={this.props.courseId}
                  />
                </TabPane>
                {/* <TabPane
                  tab={this.props.t("COURSE_DATA_SHEET_TAB_NAME_6")}
                  key="6"
                >
                  {this.state.actKey === "6" && <UnityWebBLCourseEditor />}
                </TabPane> */}
                <TabPane
                  tab={this.props.t("COURSE_DATA_SHEET_TAB_NAME_7")}
                  key="7"
                >
                  {this.state.actKey === "7" && (
                    <DocumentationPage
                      courseId={this.props.courseId}
                      // documentation={this.state.courseData.documentation}
                    ></DocumentationPage>
                  )}
                </TabPane>
              </Tabs>
            )}
          </Col>
        </Row>
      </div>
    );
  }
}
const mapStateToProps = (state) => ({
  course: state.courseReducer.course,
});
const CourseDataSheet = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedCourseDataSheet)
);
export default CourseDataSheet;
