import {EyeOutlined } from '@ant-design/icons';
import { Button, Col, Row, Table } from 'antd';
import React, { Component } from 'react';
import ReactPlayer from 'react-player/';
import { connect } from 'react-redux';
import { getCourseAllFiles } from '../../actions/file-manager'
import ReactAudioPlayer from 'react-audio-player';
import UnityWebbGL3dViewerCourseEditor from './unity-web-gl';
import Cookies from 'universal-cookie';
import { withTranslation } from 'react-i18next';
import Iframe from 'react-iframe';


const mapDispatchToProps = (dispatch) => {
    return {
        getCourseAllFiles: (courseId) => dispatch(getCourseAllFiles(courseId))
    };
};
class ConnectedCourseFilePage extends Component {
  state = {
    deleteButtonIsActive: true,
    selectedRowKeys: [],
    columns: [
      {
        title: this.props.t("COURSE_FILE_PAGE_TABLE_NAME"),
        dataIndex: "fileName",
        key: "fileName",
      },
      {
        title: this.props.t("COURSE_FILE_PAGE_TABLE_EDIT"),
        key: "showData",
        width: "5vw",
        align: "center",
        render: (text, row) => (
          <Button
            onClick={() => this.selectRow(row)}
            shape="circle"
            icon={<EyeOutlined />}
          ></Button>
        ),
      },
    ],
    fileExtension: "",
    fileURL: "",
    _3d: true,
  };

  componentDidMount = async () => {
    await this.props.getCourseAllFiles(this.props.courseId);
  };

  selectRow = (row) => {
    const cookies = new Cookies();
    // cookies.set("courseId", null, { path: "/" });
    cookies.set("baseURL", null, { path: "/" });
    this.setState({ fileExtension: undefined, fileURL: undefined }, () => {
      const file = row.fileSavedName;
      const fileExtension = row.fileSavedName.split(".")[1];
      if (
        fileExtension.toUpperCase() === "STL" ||
        fileExtension.toUpperCase() === "FBX" ||
        fileExtension.toUpperCase() === "OBJ" ||
        fileExtension.toUpperCase() === "GLTF" ||
        fileExtension.toUpperCase() === "3MF" ||
        fileExtension.toUpperCase() === "PLY"
      ) {
        const cookies = new Cookies();
        cookies.set("modelURL", row.fileSavedName, { path: "/" });
        const cookies2 = new Cookies();
        cookies2.set("baseURL", process.env.REACT_APP_API_URL + "/", {
          path: "/",
        });
        this.setState({ _3d: true });
      } else {
        this.setState({ _3d: false });
      }
      const fileURL =
        process.env.REACT_APP_API_URL +
        "/files/get-by-filename?filename=" +
        file;
      this.setState({ fileExtension: fileExtension, fileURL: fileURL });
    });
  };

  render() {
    return (
      <div>
        <Row gutter={[24, 24]}>
          <Col span={8}>
            <Table
              size="middle"
              pagination={{ position: ["bottomCenter"], pageSize: 8 }}
              rowKey="id"
              columns={this.state.columns}
              dataSource={this.props.files}
              scroll={{ y: "40vh" }}
            ></Table>
          </Col>
          <Col
            span={16}
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "flex-start",
            }}
          >
            {this.state.fileExtension && this.state.fileExtension === "mp4" && (
              <ReactPlayer
                width={"100%"}
                controls={true}
                url={this.state.fileURL}
              ></ReactPlayer>
            )}
            {this.state.fileExtension &&
              (this.state.fileExtension === "mp3" ||
                this.state.fileExtension === "wav") && (
                <ReactAudioPlayer
                  style={{ width: "100%" }}
                  src={this.state.fileURL}
                  controls
                />
              )}
            {this.state._3d === true && this.state.fileExtension && (
                             <div style={{height:"85vh", width: "100%"}}>
                  <Iframe
                    url="/webGL_3d/index.html"
                    width="100%"
                    height="100%"
                    id="myId"
                    className="myClassname"
                    display="initial"
                    position="relative"
                  />
                </div>
              // <UnityWebbGL3dViewerCourseEditor  style={{ width: "100%", height: "100%" }} />
            )}
            {this.state.fileExtension &&
              (this.state.fileExtension.toUpperCase() === "PNG" ||
                this.state.fileExtension.toUpperCase() === "JPG" ||
                this.state.fileExtension.toUpperCase() === "JPEG" ||
                this.state.fileExtension.toUpperCase() === "BMP") && (
                <img
                  src={this.state.fileURL}
                  alt="Missing pictures"
                  style={{ maxWidth: "80%" }}
                ></img>
              )}
          </Col>
        </Row>
      </div>
    );
  }
}

const mapStateToProps = (state) => ({
    files: state.fileManagerReducer.files,
    status: state.fileManagerReducer.status
});

const CourseFilePage = withTranslation()(connect(mapStateToProps, mapDispatchToProps)(ConnectedCourseFilePage));
export default CourseFilePage;