import React, { Component } from "react";
import { connect } from "react-redux";
import { Doughnut } from "react-chartjs-2";
import { Col, Row, Spin, Table } from "antd";
import { withTranslation } from "react-i18next";
import { getCourseStatistics } from "../../actions/course";
import { getAllByUserId, getAllTactActionsByTactStatisticsId, getAllTactStatisticsByUsersAndCourseID, getAllTActStatisticsUserByCourseId } from "../../actions/statistics";
import { Select } from "antd";
import { CheckCircleOutlined, CloseSquareOutlined } from "@ant-design/icons";

const { Option } = Select;

const mapDispatchToProps = (dispatch) => {
  return {
    getCourseStatistics: (courseId) => dispatch(getCourseStatistics(courseId)),
    getAllTactStatisticsByUsersAndCourseID: (userId, courseId) => dispatch(getAllTactStatisticsByUsersAndCourseID(userId, courseId)),
    getAllByUserId: (userId) => dispatch(getAllByUserId(userId)),
    getAllTActStatisticsUserByCourseId: (courseId) => dispatch(getAllTActStatisticsUserByCourseId(courseId)),
    getAllTactActionsByTactStatisticsId: (tactStatisticsId) => dispatch(getAllTactActionsByTactStatisticsId(tactStatisticsId)),
  };
};

class ConnectedCourseStatisticsPage extends Component {
  state = {
    selectedUser: {},
    successExamStudentNumber: 0,
    failExamStudentNumber: 0,
    successPracticeStudentNumber: 0,
    failPracticeStudentNumber: 0,
    selectedTactStatistics: {},
    tactActions: [],
    userStatisticsByCourseId: [],
    columns: [
      {
        title: this.props.t("COURSE_STATISTICS_TABLE_COLUMN_01"),
        key: "id",
        render: (text, row) => row.actionComment,
      },
      {
        title: this.props.t("COURSE_STATISTICS_TABLE_COLUMN_02"),
        key: "id",
        align: "center",
        render: (text, row) => row.tactTimeTarget,
      },
      {
        title: this.props.t("COURSE_STATISTICS_TABLE_COLUMN_03"),
        key: "id",
        align: "center",
        render: (text, row) => row.tactTimeCurrent,
      },
      {
        title: this.props.t("COURSE_STATISTICS_TABLE_COLUMN_04"),
        key: "id",
        align: "center",
        render: (text, row) => (
          <div>
            {row.tactTimeTarget >= row.tactTimeCurrent ? (
              <CheckCircleOutlined style={{ color: "#00FF00" }} />
            ) : (
              <CloseSquareOutlined style={{ color: "#FF0000" }} />
            )}
          </div>
        ),
      },]
  };

  componentDidMount = async () => {
    await this.props.getCourseStatistics(this.props.courseId);
    await this.props.getAllTActStatisticsUserByCourseId(this.props.courseId);
    if (
      this.props.statisticsStatus &&
      this.props.statisticsStatus === "loaded"
    ) {
      this.setState({
        successExamStudentNumber:
          this.props.statistics.successExamStudentNumber,
        failExamStudentNumber: this.props.statistics.failExamStudentNumber,
        successPracticeStudentNumber:
          this.props.statistics.successPracticeStudentNumber,
        failPracticeStudentNumber:
          this.props.statistics.failPracticeStudentNumber,
      });
    }
  };
  resetData = () => {
    this.setState({
      tactActions: [],
      userStatisticsByCourseId: []
    })
  }

  selectUser = async (param) => {
    await this.props.getAllTactStatisticsByUsersAndCourseID(param, this.props.courseId)
    if (this.props.userStatisticsByCourseId) {
      this.setState({ userStatisticsByCourseId: this.props.userStatisticsByCourseId })
    }
  }

  selectUserTact = async (tactStatisticsId) => {
    await this.props.getAllTactActionsByTactStatisticsId(tactStatisticsId)
    if (this.props.tactActions) {
      this.setState({ tactActions: this.props.tactActions })
    }
  }


  render() {
    const options = {
      legend: {
        display: true,
        position: "top",
      },
      elements: {
        arc: {
          borderWidth: 5,
        },
      },
    };
    const dataPractice = {
      labels: [
        this.props.t("STATISTICS_LABEL_USER_FINISHED_USER_NUMBER"),
        this.props.t("STATISTICS_LABEL_USER_NOT_FINISHED_USER_NUMBER"),
      ],
      datasets: [
        {
          label: "My First Dataset",
          data: [
            this.state.successPracticeStudentNumber === 0
              ? undefined
              : this.state.successPracticeStudentNumber,
            this.state.failPracticeStudentNumber === 0
              ? undefined
              : this.state.failPracticeStudentNumber
          ],
          backgroundColor: [
            "rgb(255, 99, 132)",
            "rgb(54, 162, 235)",
            "rgb(255, 205, 86)",
          ],
          hoverOffset: 4,
        },
      ],
    };
    const dataExam = {
      labels: [
        this.props.t("STATISTICS_LABEL_USER_EXAM_FINISHED_USER_NUMBER"),
        this.props.t("STATISTICS_LABEL_USER_EXAM_NOT_FINISHED_USER_NUMBER"),
      ],
      datasets: [
        {
          label: "My First Dataset",
          data: [
            this.state.successExamStudentNumber === 0
              ? undefined
              : this.state.successExamStudentNumber,
            this.state.failExamStudentNumber === 0
              ? undefined
              : this.state.failExamStudentNumber,

          ],
          backgroundColor: [
            "rgb(255, 99, 132)",
            "rgb(54, 162, 235)",
            "rgb(255, 205, 86)",
          ],
          hoverOffset: 4,
        },
      ],
    };
    return (
      <div>
        <Row gutter={24} align="middle" justify="center ">
          <Col span={12} style={{ textAlign: "center" }}>
            {this.props.t("STATISTICS_TITLE_EXAM")}
          </Col>
          <Col span={12} style={{ textAlign: "center" }}>
            {this.props.t("STATISTICS_TITLE_PRACTICE")}
          </Col>
        </Row>
        <Row gutter={24} align="middle" justify="center ">
          {this.props.statisticsStatus === "loading" ? (
            <Col span={12} style={{ textAlign: "center" }}>
              <Spin></Spin>
            </Col>
          ) : (
            <Col span={12} style={{ textAlign: "center" }}>
              {this.state.failExamStudentNumber === 0 &&
                this.state.successExamStudentNumber === 0 ? (
                <div>{this.props.t("DIAGRAM_DATA_IS_EMPTY")}</div>
              ) : (
                <Doughnut
                  height={100}
                  //   width={50}
                  data={dataExam}
                  options={options}
                ></Doughnut>
              )}
            </Col>
          )}

          {this.props.statisticsStatus === "loading" ? (
            <Col span={12} style={{ textAlign: "center" }}>
              <Spin></Spin>
            </Col>
          ) : (
            <Col span={12} style={{ textAlign: "center" }}>
              {this.state.failPracticeStudentNumber === 0 &&
                this.state.successPracticeStudentNumber === 0 ? (
                <div>{this.props.t("DIAGRAM_DATA_IS_EMPTY")}</div>
              ) : (
                <Doughnut
                  height={100}
                  //   width={50}
                  data={dataPractice}
                  options={options}
                ></Doughnut>
              )}
            </Col>
          )}
        </Row>
        <Row gutter={[24, 24]}>
          <Col span={24}><h3>Tact Statisztika</h3></Col>
          <Col span={24}>
            <Row gutter={[24, 24]}>
              <Col span={6}>
                <Col span={24}><h4>Felasználó</h4></Col>
                <Col span={24}>
                  {this.props.tactUsers && this.props.tactUsers[0] &&
                    <Select
                      style={{ width: "100%" }}
                      onChange={this.selectUser}
                    >
                      {this.props.tactUsers &&
                        this.props.tactUsers.map((item) => {
                          return (
                            <Option value={item.id}>
                              {item.firstName + " " + item.lastName}
                            </Option>
                          );
                        })}
                    </Select>
                  }
                </Col>
              </Col>


              {this.state.userStatisticsByCourseId && this.state.userStatisticsByCourseId[0] &&
                <Col span={6}>
                  <Col span={24}><h4>Dátum</h4> </Col>
                  <Col span={24}>
                    <Select
                      style={{ width: "100%" }}
                      onChange={this.selectUserTact}
                    >
                      {this.state.userStatisticsByCourseId &&
                        this.state.userStatisticsByCourseId.map((item) => {
                          return (
                            <Option value={item.id}>
                              {/* {new Date(item.created * 1000).toLocaleString()} */}
                              {new Date(item.created).toLocaleString()}
                            </Option>
                          );
                        })}
                    </Select>
                  </Col>
                </Col>}

              {this.state.tactActions && this.state.tactActions[0] && <Table
                size="middle"
                pagination={false}
                rowKey="id"
                columns={this.state.columns}
                dataSource={this.state.tactActions}
                scroll={{ y: "30vh" }}
              ></Table>}
            </Row></Col>
        </Row>

      </div>
    );
  }
}
const mapStateToProps = (state) => ({
  statisticsStatus: state.courseReducer.statisticsStatus,
  statistics: state.courseReducer.statistics,
  tactUsers: state.statisticsReducer.tactUsers,
  userStatisticsByCourseId: state.statisticsReducer.userStatisticsByCourseId,
  tactActions: state.statisticsReducer.tactActions
});
const CourseStatisticsPage = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedCourseStatisticsPage)
);
export default CourseStatisticsPage;
