import {
  DownloadOutlined,
  LeftOutlined,
  RightOutlined,
} from "@ant-design/icons";
import { Button, Col, Modal, notification, Row, Table } from "antd";
import React, { Component } from "react";
import { withTranslation } from "react-i18next";
import { connect } from "react-redux";
import {
  generateAllUserPDF,
  genereatePDF,
  setUsersToCourse,
} from "../../actions/course";
import { getAllCourseUsers } from "../../actions/user";
import { COURSE_TYPE } from "../../constants/global";
import "./course-user-page.scss";
import PdfModal from "./pdf-modal";
var QRCode = require("qrcode.react");
const mapDispatchToProps = (dispatch) => {
  return {
    getAllCourseUsers: (courseId) => dispatch(getAllCourseUsers(courseId)),
    setUsersToCourse: (obj) => dispatch(setUsersToCourse(obj)),
    genereatePDF: (obj) => dispatch(genereatePDF(obj)),
    generateAllUserPDF: (obj) => dispatch(generateAllUserPDF(obj)),
  };
};

class ConnectedCourseUserPage extends Component {
  state = {
    selectedKeys: [],
    columnsLeft: [
      {
        title: this.props.t("COURSE_USER_PAGE_TABLE_USER_NAME_LEFT"),
        key: "id",
        render: (text, row) => row.user.firstName + " " + row.user.firstName,
      },
    ],
    columnsRight: [
      {
        title: this.props.t("COURSE_USER_PAGE_TABLE_USER_NAME_RIGHT"),
        key: "id",
        render: (text, row) => row.user.firstName + " " + row.user.firstName,
      },
      {
        title: this.props.t("COURSE_USER_PAGE_TABLE_QR"),
        key: "id",
        render: (text, row) => (
          <QRCode
            value={row.qr}
            level="Q"
            style={{
              height: "3vh",
              width: "3vh",
              cursor: "zoom-in",
            }}
            onClick={() => this.showQR(row.qr)}
          />
        ),
      },
      {
        title: this.props.t("COURSE_EXAMINEES_PAGE_TABLE_PDF"),
        key: "id",
        align: "center",
        render: (text, row) => (
          <div>
            <Button
              loading={this.state.loadingUserid === row.id ? true : false}
              disabled={
                this.state.loadingUserid === row.id
                  ? false
                  : this.state.pdfButtonsdisabled
              }
              onClick={async () => await this.generateUserPDF(row)}
            >
              PDF
            </Button>
          </div>
        ),
      },
    ],
    users: [],
    initUsersIDs: [],
    initSelectedUsers: [],
    selectedUsers: [],
    selectedRowKeysLeft: [],
    selectedRowKeysRight: [],
    showQR: false,
    actualQR: "",
    pdfButtonsdisabled: false,
    allPdfDowloadDisabled: false,
    allPdfDownloadLoading: false,
  };
  getUsersDataAndSetIdsArrays = async () => {
    await this.props.getAllCourseUsers(this.props.courseId);
    if (this.props.users) {
      let _initUserIds = [];
      let _initSelectedUsersIds = [];
      for (
        let index = 0;
        index < this.props.users.allUserWithoutCourseUser.length;
        index++
      ) {
        const element = this.props.users.allUserWithoutCourseUser[index];
        _initUserIds = [..._initUserIds, element.id];
      }
      for (
        let index = 0;
        index < this.props.users.courseUsers.length;
        index++
      ) {
        const element = this.props.users.courseUsers[index];
        _initSelectedUsersIds = [..._initSelectedUsersIds, element.id];
      }
      this.setState({
        users: this.props.users.allUserWithoutCourseUser,
        selectedUsers: this.props.users.courseUsers,
        initUsersIDs: _initUserIds,
        initSelectedUsers: _initSelectedUsersIds,
      });
    }
  };

  componentDidMount = async () => {
    await this.getUsersDataAndSetIdsArrays();
  };

  saveList = async () => {
    let users = [];
    for (let index = 0; index < this.state.selectedUsers.length; index++) {
      const element = this.state.selectedUsers[index];
      users = [
        ...users,
        {
          userId: element.user.id,
          qr: element.qr,
        },
      ];
    }
    const obj = {
      courseTypeId: 1,
      courseId: this.props.courseId,
      users: users,
    };
    await this.props.setUsersToCourse(obj);
    await this.getUsersDataAndSetIdsArrays();
    this.setState({ allPdfDowloadDisabled: false });
  };

  showQR(qr) {
    this.setState({ showQR: true, actualQR: qr });
  }
  onSelectChangeLeft = (selectedRowKeysLeft) => {
    this.setState({ selectedRowKeysLeft });
  };
  onSelectChangeRight = (selectedRowKeysRight) => {
    this.setState({ selectedRowKeysRight });
  };
  moveUserLeftToRight = () => {
    const filterArray = this.state.users.filter(
      (item) => !this.state.selectedRowKeysLeft.includes(item.id)
    );
    const filter2 = this.state.users.filter((item) =>
      this.state.selectedRowKeysLeft.includes(item.id)
    );
    this.setState(
      {
        users: filterArray,
        selectedUsers: [...this.state.selectedUsers, ...filter2],
        allPdfDowloadDisabled: true,
      },
      () => this.checkTwoTableEqualInitData()
    );
  };
  moveUserRigtToLeft = () => {
    const filterArray = this.state.selectedUsers.filter(
      (item) => !this.state.selectedRowKeysRight.includes(item.id)
    );
    const filter2 = this.state.selectedUsers.filter((item) =>
      this.state.selectedRowKeysRight.includes(item.id)
    );
    this.setState(
      {
        selectedUsers: filterArray,
        users: [...this.state.users, ...filter2],
        allPdfDowloadDisabled: true,
      },
      () => this.checkTwoTableEqualInitData()
    );
  };
  checkTwoTableEqualInitData = () => {
    let _actUserIds = [];
    let _actSelectedUsersIds = [];
    for (let index = 0; index < this.state.users.length; index++) {
      const element = this.state.users[index];
      _actUserIds = [..._actUserIds, element.id];
    }
    for (let index = 0; index < this.state.selectedUsers.length; index++) {
      const element = this.state.selectedUsers[index];
      _actSelectedUsersIds = [..._actSelectedUsersIds, element.id];
    }
    if (
      _actUserIds.sort().toString() ===
        this.state.initUsersIDs.sort().toString() &&
      _actSelectedUsersIds.sort().toString() ===
        this.state.initSelectedUsers.sort().toString()
    ) {
      this.setState({ allPdfDowloadDisabled: false });
    }
  };

  closeQR = () => {
    this.setState({ showQR: false });
  };
  closePDF = () => {
    this.setState({ pdfOpen: false });
  };

  openPDF = (row) => {
    const fileOutName = row.user.name + "_" + this.props.courseName + "_tanulo";
    this.setState({ pdfOpen: true, fileOutName: fileOutName });
  };

  generateUserPDF = (row) => {
    this.setState(
      {
        loadingUserid: row.id,
        pdfButtonsdisabled: true,
      },
      async () => {
        const obj = {
          qrCode: row.qr,
          userId: row.user.id,
          courseId: this.props.courseId,
          courseTypeId: COURSE_TYPE.base,
        };
        await this.props.genereatePDF(obj);
        this.setState({
          loadingUserid: "",
          pdfButtonsdisabled: false,
        });
        if (this.props.pdfstatus === "loaded") {
          this.setState(
            {
              selectedPDFurl: process.env.REACT_APP_API_URL + this.props.pdfURL,
            },
            () => {
              this.openPDF(row);
            }
          );
        } else {
          notification["error"]({
            message: this.props.t("PDF_LOAD_ERROR_TITLE"),
            description: this.props.t("PDF_LOAD_ERROR_DESCRIPTION"),
            onClick: () => {},
          });
        }
      }
    );
  };

  generateAllUserPDF = async () => {
    this.setState({ allPdfDownloadLoading: true });
    let obj = [];
    for (let index = 0; index < this.state.selectedUsers.length; index++) {
      const element = this.state.selectedUsers[index];
      const actUser = {
        qrCode: element.qr,
        userId: element.user.id,
        courseId: this.props.courseId,
        courseTypeId: COURSE_TYPE.base,
      };
      obj = [...obj, actUser];
    }
    await this.props.generateAllUserPDF(obj);
    this.setState({ allPdfDownloadLoading: false });
    const link = document.createElement("a");
    link.href = process.env.REACT_APP_API_URL + this.props.allPdfURL;
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
  };

  render() {
    const { selectedRowKeysLeft, selectedRowKeysRight } = this.state;
    const rowSelection_left = {
      selectedRowKeysLeft,
      onChange: this.onSelectChangeLeft,
    };
    const rowSelection_right = {
      selectedRowKeysRight,
      onChange: this.onSelectChangeRight,
    };

    return (
      <div>
        <Row justify="space-between">
          <Button type="primary" onClick={() => this.saveList()}>
            {this.props.t("COURSE_USER_PAGE_BUTTON_SAVE")}
          </Button>
          <Button
            type="primary"
            icon={<DownloadOutlined />}
            disabled={this.state.allPdfDowloadDisabled}
            loading={false}
            onClick={() => this.generateAllUserPDF()}
          >
            {this.props.t("COURSE_EXAMINEES_PAGE_GENERATE_PDF_ALL_EXAMINER")}
          </Button>
        </Row>
        <Row gutter={[24, 24]}>
          <Col span={8}>
            <h3>{this.props.t("COURSE_USER_PAGE_STUDENT_TITLE")}</h3>
            <Table
              size="middle"
              pagination={false}
              rowKey="id"
              columns={this.state.columnsLeft}
              dataSource={this.state.users}
              rowSelection={rowSelection_left}
              scroll={{ y: "80vh" }}
            ></Table>
          </Col>
          <Col span={2}>
            <Row
              gutter={[10, 10]}
              style={{ height: "50%" }}
              align="bottom"
              justify="center"
            >
              <Col>
                <Button
                  disabled={
                    this.state.selectedRowKeysRight.length === 0 ? true : false
                  }
                  onClick={this.moveUserRigtToLeft}
                >
                  <LeftOutlined />
                </Button>
              </Col>
            </Row>
            <Row
              gutter={[10, 10]}
              style={{ height: "50%" }}
              align="top"
              justify="center"
            >
              <Col>
                <Button
                  disabled={
                    this.state.selectedRowKeysLeft.length === 0 ? true : false
                  }
                  onClick={this.moveUserLeftToRight}
                >
                  <RightOutlined />
                </Button>
              </Col>
            </Row>
          </Col>
          <Col span={14}>
            <h3>{this.props.t("COURSE_USER_PAGE_STUDENT_ACTIVE_TITLE")}</h3>
            <Table
              size="middle"
              pagination={false}
              rowKey="id"
              columns={this.state.columnsRight}
              dataSource={this.state.selectedUsers}
              rowSelection={rowSelection_right}
              scroll={{ y: "80vh" }}
            ></Table>
          </Col>
        </Row>
        <Modal
          title={this.props.t("QR_MODAL")}
          visible={this.state.showQR}
          onCancel={this.closeQR}
        >
          <Row align="bottom" justify="center" id="divcontents">
            <Col id="ifmcontentstoprint">
              <QRCode
                style={{ visibility: "visible" }}
                id="123456"
                value={this.state.actualQR}
                size={400}
                level="Q"
              />
            </Col>
            <Col></Col>
          </Row>
        </Modal>
        <Modal
          title="Felhasználó kurzus adatok"
          onCancel={this.closePDF}
          visible={this.state.pdfOpen}
          footer={null}
          centered={true}
          width="auto"
          style={{ overflow: "hidden" }}
        >
          <page size="A4">
            <PdfModal
              fileOutName={this.state.fileOutName}
              selectedPDFurl={this.state.selectedPDFurl}
            ></PdfModal>
          </page>
        </Modal>
      </div>
    );
  }
}
const mapStateToProps = (state) => ({
  users: state.userReducer.courseUsers,
  pdfURL: state.courseReducer.pdfURL,
  pdfstatus: state.courseReducer.pdfstatus,
  allPdfURL: state.courseReducer.allPdfURL,
  allPdfstatus: state.courseReducer.allPdfstatus,
});
const CourseUserPage = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedCourseUserPage)
);
export default CourseUserPage;
