import {
  DeleteOutlined,
  EyeOutlined,
  QuestionCircleOutlined,
  SearchOutlined,
} from "@ant-design/icons";
import {
  Button,
  Col,
  Drawer,
  Modal,
  Row,
  Table,
  List,
  Input,
  Space,
} from "antd";
import React, { Component } from "react";
import { withTranslation } from "react-i18next";
import { connect } from "react-redux";
import {
  deleteFile,
  getAllCourseByFile,
  getAllFiles,
} from "../../actions/file-manager";
import Cookies from "universal-cookie";
import ReactPlayer from "react-player";
import ReactAudioPlayer from "react-audio-player";
import UnityWebbGL3dViewerCourseEditor from "../course/unity-web-gl";
import NewFileModal from "./new-file-modal";

import Highlighter from "react-highlight-words";
import Iframe from "react-iframe";

const mapDispatchToProps = (dispatch) => {
  return {
    getAllFiles: () => dispatch(getAllFiles()),
    deleteFile: (fileId) => dispatch(deleteFile(fileId)),
    getAllCourseByFile: (fileId) => dispatch(getAllCourseByFile(fileId)),
  };
};

class ConnectedFileManagerBase extends Component {
  state = {
    fileList: [],
    fileExtension: "",
    fileURL: "",
    _3d: true,
    newFileModalOpen: false,
    isCourseListModalOpen: false,
    showFile :false
  };

  componentDidMount = async () => {
    await this.props.getAllFiles();
    this.convertFileList();
  };

  convertFileList = () => {
    let fileArray = [];
    if (this.props.status && this.props.status === "loaded") {
      for (let index = 0; index < this.props.allFiles.length; index++) {
        const element = this.props.allFiles[index];
        if (element.tag === undefined || element.tag === null) {
          element.tag = "n/a";
        }
        switch (element.fileTypeId) {
          case 1:
            element.type = "Ismeretlen";
            break;
          case 2:
            element.type = "Kép";
            break;
          case 3:
            element.type = "Hang";
            break;
          case 4:
            element.type = "Video";
            break;
          case 5:
            element.type = "3D";
            break;
          default:
            element.type = "ismeretlen";
            break;
        }

        fileArray = [...fileArray, element];
      }
      this.setState({ fileList: fileArray });
    }
  };
  selectRow = (row) => {
    const cookies = new Cookies();
    cookies.set("courseId", null, { path: "/" });
    cookies.set("baseURL", null, { path: "/" });
    this.setState({ fileExtension: undefined, fileURL: undefined }, () => {
      const file = row.fileSavedName;
      const fileExtension = row.fileSavedName.split(".")[1];
      if (
        fileExtension &&
        (fileExtension.toUpperCase() === "STL" ||
          fileExtension.toUpperCase() === "FBX" ||
          fileExtension.toUpperCase() === "OBJ" ||
          fileExtension.toUpperCase() === "GLTF" ||
          fileExtension.toUpperCase() === "3MF" ||
          fileExtension.toUpperCase() === "PLY" ||
          fileExtension.toUpperCase() === "ZIP" 
          )
        
      ) {
        const cookies = new Cookies();
        cookies.set("modelURL", row.fileSavedName, { path: "/" });
        const cookies2 = new Cookies();
        cookies2.set("baseURL", process.env.REACT_APP_API_URL + "/", {
          path: "/",
        });
        this.setState({ _3d: true });
      } else {
        this.setState({ _3d: false });
      }
      const fileURL =
        process.env.REACT_APP_API_URL +
        "/files/get-by-filename?filename=" +
        file;
      this.setState({ fileExtension: fileExtension, fileURL: fileURL , showFile :true});
    });
  };
  getColumnSearchProps = (dataIndex) => ({
    filterDropdown: ({
      setSelectedKeys,
      selectedKeys,
      confirm,
      clearFilters,
    }) => (
      <div style={{ padding: 8 }}>
        <Input
          ref={(node) => {
            this.searchInput = node;
          }}
          placeholder={`Search ${dataIndex}`}
          value={selectedKeys[0]}
          onChange={(e) =>
            setSelectedKeys(e.target.value ? [e.target.value] : [])
          }
          onPressEnter={() =>
            this.handleSearch(selectedKeys, confirm, dataIndex)
          }
          style={{ width: 188, marginBottom: 8, display: "block" }}
        />
        <Space>
          <Button
            type="primary"
            onClick={() => this.handleSearch(selectedKeys, confirm, dataIndex)}
            icon={<SearchOutlined />}
            size="small"
            style={{ width: 90 }}
          >
            Keresés
          </Button>
          <Button
            onClick={() => this.handleReset(clearFilters)}
            size="small"
            style={{ width: 90 }}
          >
            Törlés
          </Button>
        </Space>
      </div>
    ),
    filterIcon: (filtered) => (
      <SearchOutlined style={{ color: filtered ? "#1890ff" : undefined }} />
    ),
    onFilter: (value, record) =>
      record[dataIndex]
        ? record[dataIndex]
            .toString()
            .toLowerCase()
            .includes(value.toLowerCase())
        : "",
    onFilterDropdownVisibleChange: (visible) => {
      if (visible) {
        setTimeout(() => this.searchInput.select(), 100);
      }
    },
    render: (text) =>
      this.state.searchedColumn === dataIndex ? (
        <Highlighter
          highlightStyle={{ backgroundColor: "#ffc069", padding: 0 }}
          searchWords={[this.state.searchText]}
          autoEscape
          textToHighlight={text ? text.toString() : ""}
        />
      ) : (
        text
      ),
  });
  handleSearch = (selectedKeys, confirm, dataIndex) => {
    confirm();
    this.setState({
      searchText: selectedKeys[0],
      searchedColumn: dataIndex,
    });
  };
  handleReset = (clearFilters) => {
    clearFilters();
    this.setState({ searchText: "" });
  };
  deleteRow = async (row) => {
    await this.props.deleteFile(row.id);
    await this.props.getAllFiles();
    if (this.props.status && this.props.status === "loaded") {
      this.convertFileList();
    }
  };

  showFileData = async (row) => {
    await this.props.getAllCourseByFile(row.id);
    this.setState({ isCourseListModalOpen: true });
  };
  closeCourseList = () => {
    this.setState({ isCourseListModalOpen: false });
  };
  closeNewFile = async () => {
    this.setState({ newFileModalOpen: false });
    await this.props.getAllFiles();
    if (this.props.status && this.props.status === "loaded") {
      this.convertFileList();
    }
  };
  openNewFile = () => {
    this.setState({ newFileModalOpen: true });
  };
  openShowFile = () => {
    this.setState({ showFile : true});
  }
  closeShowFile = () => {
    this.setState({ showFile : false});
  }
  render() {
    const fileColumns = [
      {
        title: this.props.t("FILE_MANAGER_FILE_PAGE_TABLE_NAME_TAG"),
        dataIndex: "tag",
        key: "tag",
        // width: "10vh",
        align: "center",
        sorter: (a, b) => a.tag.localeCompare(b.tag),

        ...this.getColumnSearchProps("tag"),
      },
      {
        title: this.props.t("FILE_MANAGER_FILE_PAGE_TABLE_NAME_TYPE"),
        dataIndex: "type",
        key: "type",
        // width: "10vh",
        align: "center",
        sorter: (a, b) => a.type.localeCompare(b.type),

        ...this.getColumnSearchProps("type"),
      },
      {
        title: this.props.t("FILE_MANAGER_FILE_PAGE_TABLE_NAME"),
        dataIndex: "fileName",
        key: "fileName",
        width: "2vw",
        sorter: (a, b) => a.fileName.localeCompare(b.fileName),
        ...this.getColumnSearchProps("fileName"),
      },
      {
        title: this.props.t("FILE_MANAGER_FILE_PAGE_TABLE_EDIT"),
        key: "showData",
        // width: "5vw",
        align: "center",
        render: (text, row) => (
          <Button
            onClick={() => this.selectRow(row)}
            shape="circle"
            icon={<EyeOutlined />}
          ></Button>
        ),
      },
      {
        title: this.props.t("FILE_MANAGER_FILE_PAGE_TABLE_DELETE"),
        key: "showData",
        // width: "5vw",
        align: "center",
        render: (text, row) =>
          !row.connected ? (
            <Button
              onClick={() => this.deleteRow(row)}
              shape="circle"
              icon={<DeleteOutlined />}
            ></Button>
          ) : (
            <Button
              onClick={() => this.showFileData(row)}
              shape="circle"
              icon={<QuestionCircleOutlined />}
            ></Button>
          ),
      },
    ];

    return (
      <React.Fragment>
        <Row>
          <h1>{this.props.t("FILE_MANAGER_TITLE")}</h1>
        </Row>
        <Row gutter={[24, 24]}>
          <Col span={24}>
            <Button type="primary" onClick={this.openNewFile}>
              {this.props.t("BUTTON_ADD_MEW_FILE")}
            </Button>
          </Col>
        </Row>
        <Row gutter={[24, 24]}>
          <Col span={24}>
            <Table
              size="small"
              pagination={{ position: ["bottomCenter"], pageSize: 8 }}
              rowKey="id"
              columns={fileColumns}
              dataSource={this.state.fileList}
              // scroll={{ y: "60vh" }}
            ></Table>
          </Col>
          {/* <Col
            span={10}
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "flex-start",
            }}
          > */}
          <Drawer
            width={"80%"}
            destroyOnClose={true}
            visible={this.state.showFile}
            title={this.props.t("DRAWER_SHOW_FILE_TITLE")}
            onCancel={this.closeShowFile}
            onClose={this.closeShowFile}
            maskClosable={false}
            footer={
              <div>
                <Button onClick={this.closeShowFile}>
                  {this.props.t("BUTTON_CANCEL")}
                </Button>
              </div>
            }
          >
            <Row gutter={24} justify="center" align="middle">
              {this.state.fileExtension &&
                this.state.fileExtension === "mp4" && (
                  <ReactPlayer
                    width={"100%"}
                    controls={true}
                    url={this.state.fileURL}
                  ></ReactPlayer>
                )}
              {this.state.fileExtension &&
                (this.state.fileExtension === "mp3" ||
                  this.state.fileExtension === "wav") && (
                  <ReactAudioPlayer
                    // style={{ width: "100%" }}
                    src={this.state.fileURL}
                    controls
                  />
                )}
              {this.state._3d === true && this.state.fileExtension && (
                // <UnityWebbGL3dViewerCourseEditor />
                <div style={{height:"85vh", width: "100%"}}>
                  <Iframe
                    url="/webGL_3d/index.html"
                    width="100%"
                    height="100%"
                    id="myId"
                    className="myClassname"
                    display="initial"
                    position="relative"
                  />
                </div>
              )}
              {this.state.fileExtension &&
                (this.state.fileExtension.toUpperCase() === "PNG" ||
                  this.state.fileExtension.toUpperCase() === "JPG" ||
                  this.state.fileExtension.toUpperCase() === "JPEG" ||
                  this.state.fileExtension.toUpperCase() === "BMP") && (
                  <img
                    src={this.state.fileURL}
                    alt="Missing pictures"
                    style={{ maxWidth: "50%", maxHeight: "60vh" }}
                  ></img>
                )}
            </Row>
          </Drawer>
        </Row>
        <Drawer
          width={"40%"}
          destroyOnClose={true}
          visible={this.state.newFileModalOpen}
          title={this.props.t("DRAWER_NEW_FILE_TITLE")}
          onCancel={this.closeNewFile}
          onClose={this.closeNewFile}
          maskClosable={false}
          footer={
            <div>
              <Button onClick={this.closeNewFile}>
                {this.props.t("BUTTON_CANCEL")}
              </Button>
            </div>
          }
        >
          <NewFileModal closeNewFile={this.closeNewFile}></NewFileModal>
        </Drawer>
        <Modal
          title={this.props.t("COURSE_LIST_FILES_TITLE")}
          visible={this.state.isCourseListModalOpen}
          onOk={this.closeCourseList}
          onCancel={this.closeCourseList}
        >
          <List
            style={{ maxHeight: "40vh", overflow: "auto" }}
            // header={<div>Header</div>}
            // footer={<div>Footer</div>}
            // bordered
            dataSource={this.props.courseList}
            renderItem={(item) => <List.Item>{item.name}</List.Item>}
          />
        </Modal>
      </React.Fragment>
    );
  }
}
const mapStateToProps = (state) => ({
  allFiles: state.fileManagerReducer.allFiles,
  status: state.fileManagerReducer.status,
  courseList: state.fileManagerReducer.courseList,
});
const FileManagerBase = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedFileManagerBase)
);
export default FileManagerBase;
