import { InboxOutlined } from "@ant-design/icons";
import { Button, Col, Input, message, Row } from "antd";
import Dragger from "antd/lib/upload/Dragger";
import React, { Component } from "react";
import { withTranslation } from "react-i18next";
import { connect } from "react-redux";
import { getAllCourseByUser } from "../../actions/course";
import { uploadFiles } from "../../actions/file-manager";
const mapDispatchToProps = (dispatch) => {
  return {
    getAllCourseByUser: () => dispatch(getAllCourseByUser()),
    uploadFiles: (formData) => dispatch(uploadFiles(formData)),
  };
};

class ConnectedNewFileModal extends Component {
  state = {
    fileList: [],
    uploading: false,
    tag: "",
    tagCharacterlimit: 20,
    limit: 20,
  };
  handleUpload = async () => {
    const { fileList } = this.state;
    const formData = new FormData();
    fileList.forEach((file) => {
      formData.append("file", file);
    });
    formData.append("tag", this.state.tag);

    this.setState({
      uploading: true,
    });
    await this.props.uploadFiles(formData);
    if (this.props.status && this.props.status === "saved") {
      this.setState({
        uploading: false,
      });
      message.success(this.props.t("FILE_UPLOAD_SUCCESS"));
      this.props.closeNewFile();
    }
    if (this.props.status && this.props.status === "error") {
      this.setState({
        uploading: false,
      });
      if (this.props.code === 2004) {
        message.error(this.props.t("FILE_UPLOAD_FAIL_TAG_NOT_UNIQUE"));
      }
      else if (this.props.code === 2005) {
         message.error(this.props.t("FILE_UPLOAD_FAIL_NOT_SUPPORTED_FILE"));
      } else {
        message.error(this.props.t("FILE_UPLOAD_FAIL"));
      }
    }
  };
  changeTag = (event) => {
    const value = event.target.value;
    const limit = this.state.limit - value.length;
    if (limit >= 0) {
      this.setState({ tag: value, tagCharacterlimit: limit });
    } else {
      this.setState({ tagCharacterlimit: 0 });
    }
  };

  render() {
    const { uploading, fileList } = this.state;
    const props = {
      accept: ".png,.jpg,.jpeg,.bmp,.mp4,.mp3,.wav,.fbx,.obj,.gltf,.stl,.ply,.3mf,.zip",
      name: "file",
      multiple: false,
      onRemove: (file) => {
        this.setState((state) => {
          const index = state.fileList.indexOf(file);
          const newFileList = state.fileList.slice();
          newFileList.splice(index, 1);
          return {
            fileList: newFileList,
          };
        });
      },
      beforeUpload: (file) => {
        this.setState((state) => ({
          fileList: [file],
        }));
        return false;
      },
      fileList,
    };
    return (
      <React.Fragment>
        <Row gutter={24} justify="space-between" align="middle">
          <Col>
            <Button
              type="primary"
              onClick={this.handleUpload}
              disabled={fileList.length === 0}
              loading={uploading}
              // style={{ marginTop: 16 }}
            >
              {uploading
                ? this.props.t("FILE_UPLOAD_BUTTON_ACTIVE")
                : this.props.t("FILE_UPLOAD_BUTTON_PROGRESS")}
            </Button>
          </Col>
          <Col>
            <Input
              addonBefore="TAG:"
              addonAfter={String(this.state.tagCharacterlimit)}
              style={{ marginLeft: "1em" }}
              value={this.state.tag}
              onChange={this.changeTag}
            ></Input>
          </Col>
        </Row>
        <Row gutter={24} align="middle">
          <Col span={24}>
            <Dragger {...props} style={{ width: "100%", marginTop: "16px" }}>
              <p className="ant-upload-drag-icon">
                <InboxOutlined />
              </p>
              <p className="ant-upload-text">
                {this.props.t("FILE_UPLOAD_AREA_TITLE")}
              </p>
              <p className="ant-upload-hint">
                {this.props.t("FILE_UPLOAD_AREA_DESCRIPTION")}
              </p>
              <p className="ant-upload-hint">
                .png,.jpg,.jpeg,.bmp,.mp4,.mp3,.wav,.fbx,.obj,.gltf,.stl,.ply,.3mf
              </p>
            </Dragger>
          </Col>

          {/* <Upload {...props}>
            <Button icon={<UploadOutlined />}>Select File</Button>
          </Upload> */}
        </Row>
      </React.Fragment>
    );
  }
}
const mapStateToProps = (state) => ({
  status: state.fileManagerReducer.status,
  code: state.fileManagerReducer.code,
});
const NewFileModal = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedNewFileModal)
);
export default NewFileModal;
