import {
  ApartmentOutlined,
  BulbTwoTone,
  DeleteOutlined,
  EyeOutlined,
  SearchOutlined,
} from "@ant-design/icons";
import {
  Button,
  Col,
  Drawer,
  Input,
  notification,
  Popconfirm,
  Row,
  Space,
  Switch,
  Table,
  Tooltip,
} from "antd";
import React, { Component } from "react";
import { connect } from "react-redux";
import Cookies from "universal-cookie";
import {
  deleteCourseByCourseID,
  duplicateCourse,
  getAllCourseByUser,
  setActiveOrDeactiveCourse,
} from "../../actions/course";
import UnityWebBLCourseEditor from "../unity/unity-web-gl";
import CourseDataSheet from "../course/course-data-sheet";
import { withTranslation } from "react-i18next";
import { getAllLanguages } from "../../actions/languge";
import { COURSE_MODUL_TYPE } from "../../constants/global";
import moment from "moment";
import Highlighter from "react-highlight-words";
import { setFilter } from "../../actions/filter";
import { FILTER } from "../../constants/action-types";

const mapDispatchToProps = (dispatch) => {
  return {
    getAllCourseByUser: () => dispatch(getAllCourseByUser()),
    deleteCourseByCourseID: (courseId) =>
      dispatch(deleteCourseByCourseID(courseId)),
    duplicateCourse: (courseId) => dispatch(duplicateCourse(courseId)),
    setActiveOrDeactiveCourse: (data) =>
      dispatch(setActiveOrDeactiveCourse(data)),
    getAllLanguages: () => dispatch(getAllLanguages()),
    setFilter: (type, sortedInfo) => dispatch(setFilter(type, sortedInfo)),
  };
};

class ConnectedLanding extends Component {
  state = {
    courseActive: false,
    courseEditorOpen: false,
    courseDataSheetOpen: false,
    selectedCourseId: null,
    actualCourse: {},
    intervalId: null,
    sortedInfo: {},
    pageSize: 10,
    current: 1,
  };
  componentDidMount = async () => {
    await this.props.getAllLanguages();
    await this.props.getAllCourseByUser();
    // if (
    //   this.props.searchOptionsCourseBase &&
    //   this.props.searchOptionsCourseBase.selectedKeys
    // ) {
    //   this.handleSearch(
    //     this.props.searchOptionsCourseBase.selectedKeys,
    //     this.props.searchOptionsCourseBase.confirm,
    //     this.props.searchOptionsCourseBase.dataIndex
    //   );
    // };
    if (this.props.sortedInfo && this.props.sortedInfo.order) {
      this.setState({ sortedInfo: this.props.sortedInfo });
    }
    if (this.props.currentBaseCourseTab) {
      this.setState({ current: this.props.currentBaseCourseTab });
    }
    const i = setInterval(() => {
      const webGLStatus = this.checkCookies();
      if (this.state.courseActive !== webGLStatus) {
        this.setState({ courseActive: webGLStatus });
      }
    }, 1000);
    this.setState({ intervalId: i });
  };

  componentWillUnmount() {
    clearInterval(this.state.intervalId);
  }

  selectRow = (row) => {
    // this.openCourseEditor()
    this.openCourseDataSheet();
    this.setState({ selectedCourseId: row.id });
    const cookies = new Cookies();
    cookies.set("courseId", row.id, { path: "/" });
    cookies.set("courseModulTypeId", row.courseModulType.id, { path: "/" });
  };

  deleteRow = async (row) => {
    await this.props.deleteCourseByCourseID(row.id);
    if (this.props.deleteStatus === "deleted") {
      notification["success"]({
        message: this.props.t("COURSE_NOTIFICATION_SUCCES_DELETE_COURSE_TITLE"),
        description: this.props.t(
          "COURSE_NOTIFICATION_SUCCES_DELETE_COURSE_DESCRIPTION"
        ),
        onClick: () => {},
      });
      await this.props.getAllCourseByUser();
    } else {
      notification["error"]({
        message: this.props.t(
          "COURSE_NOTIFICATION_NOT_SUCCES_DELETE_COURSE_TITLE"
        ),
        description: this.props.t(
          "COURSE_NOTIFICATION_NOT_SUCCES_DELETE_COURSE_DESCRIPTION"
        ),
        onClick: () => {},
      });
    }
  };
  cancelDelete = (row) => {};

  duplicateRow = async (row) => {
    await this.props.duplicateCourse(row.id);
    await this.props.getAllCourseByUser();
  };
  isActiveChange = async (row) => {
    const data = {
      courseId: row.id,
      isActive: !row.isActive,
    };
    await this.props.setActiveOrDeactiveCourse(data);
    await this.props.getAllCourseByUser();
  };
  cancelDuplicate = (row) => {};

  openCourseEditor = () => {
    this.setState({ courseEditorOpen: true });
  };

  closeCourseEditor = async () => {
    this.setState({ courseEditorOpen: false });
    const cookies = new Cookies();
    cookies.remove("courseId");
    cookies.remove("courseModulTypeId");
    await this.props.getAllCourseByUser();
  };
  openCourseDataSheet = () => {
    this.setState({ courseDataSheetOpen: true });
  };

  closeCourseDataSheet = async () => {
    this.setState({ courseDataSheetOpen: false });
    const cookies = new Cookies();
    cookies.remove("courseId");
    cookies.remove("courseModulTypeId");
    await this.props.getAllCourseByUser();
  };

  createNewCourse = async () => {
    const cookies = new Cookies();
    cookies.set("courseId", null, { path: "/" });
    cookies.set("courseModulTypeId", 1, { path: "/" });
    this.setState({ createNewCourse: true });
    await this.props.getAllCourseByUser();
  };

  closeCreateNewCourse = () => {
    this.setState({ createNewCourse: false });
    const cookies = new Cookies();
    cookies.remove("courseId");
    cookies.remove("courseModulTypeId");
  };
  setCourse = (course) => {
    this.setState({ actualCourse: course });
  };

  openNewCourseInNewTab = async () => {
    const cookies = new Cookies();
    cookies.set("courseId", null, { path: "/" });
    cookies.set("courseModulTypeId", COURSE_MODUL_TYPE.normal, { path: "/" });

    await this.props.getAllCourseByUser();
    window.open("/unity");
  };
  checkCookies = () => {
    const cookies = new Cookies();
    const a = cookies.get("isEditorOpen");
    if (a === "false") {
      return false;
    } else {
      return true;
    }
  };
  handleSearch = (selectedKeys, confirm, dataIndex) => {
    confirm();

    const searchInfo = {
      selectedKeys: selectedKeys,
      confirm: confirm,
      dataIndex: dataIndex,
    };
    this.setState({
      searchText: selectedKeys[0],
      searchedColumn: dataIndex,
    });
    this.props.setFilter(FILTER.BASE_COURSE_SEARCH_KEYS, searchInfo);
  };
  handleReset = (clearFilters) => {
    clearFilters();
    this.setState({ searchText: "" });
    this.props.setFilter(FILTER.BASE_COURSE_SEARCH_KEYS_RESET, []);
  };

  handleChangeTable = (pagination, filters, sorter) => {
    this.setState({
      sortedInfo: sorter,
      pageSize: pagination.pageSize,
      current: pagination.current,
    });
    // this.props.setFilter(FILTER.BASE_COURSE, sorter);
    // this.props.setFilter(
    //   TAB_HELPER.BASE_COURSE_CURRENT_TAB,
    //   pagination.current
    // );
  };
  getColumnSearchProps = (dataIndex) => ({
    filterDropdown: ({
      setSelectedKeys,
      selectedKeys,
      confirm,
      clearFilters,
    }) => (
      <div style={{ padding: 8 }}>
        <Input
          ref={(node) => {
            this.searchInput = node;
          }}
          placeholder={`Search ${dataIndex}`}
          value={selectedKeys[0]}
          onChange={(e) =>
            setSelectedKeys(e.target.value ? [e.target.value] : [])
          }
          onPressEnter={() =>
            this.handleSearch(selectedKeys, confirm, dataIndex)
          }
          style={{ width: 188, marginBottom: 8, display: "block" }}
        />
        <Space>
          <Button
            type="primary"
            onClick={() => this.handleSearch(selectedKeys, confirm, dataIndex)}
            icon={<SearchOutlined />}
            size="small"
            style={{ width: 90 }}
          >
            Keresés
          </Button>
          <Button
            onClick={() => this.handleReset(clearFilters)}
            size="small"
            style={{ width: 90 }}
          >
            Törlés
          </Button>
        </Space>
      </div>
    ),
    filterIcon: (filtered) => (
      <SearchOutlined style={{ color: filtered ? "#1890ff" : undefined }} />
    ),
    onFilter: (value, record) =>
      record[dataIndex]
        ? record[dataIndex]
            .toString()
            .toLowerCase()
            .includes(value.toLowerCase())
        : "",
    onFilterDropdownVisibleChange: (visible) => {
      if (visible) {
        setTimeout(() => this.searchInput.select(), 100);
      }
    },
    render: (text) =>
      this.state.searchedColumn === dataIndex ? (
        <Highlighter
          highlightStyle={{ backgroundColor: "#ffc069", padding: 0 }}
          searchWords={[this.state.searchText]}
          autoEscape
          textToHighlight={text ? text.toString() : ""}
        />
      ) : (
        text
      ),
  });

  render() {
    let { sortedInfo } = this.state;
    sortedInfo = sortedInfo || {};
    const columns = [
      {
        title: this.props.t("COURSE_TABLE_STATUS"),
        dataIndex: "name",
        key: "name",
        align: "center",
        width: "5vw",
        render: (text, row) => {
          return row.courseStatus && row.courseStatus.id === 1 ? (
            <Tooltip title={this.props.t("STATUS_1")}>
              <BulbTwoTone twoToneColor="#ffcc00" style={{ fontSize: "2em" }} />
            </Tooltip>
          ) : row.courseStatus.id === 2 ? (
            <Tooltip title={this.props.t("STATUS_2")}>
              <BulbTwoTone twoToneColor="#42f56c" style={{ fontSize: "2em" }} />
            </Tooltip>
          ) : (
            <Tooltip title={this.props.t("STATUS_3")}>
              <BulbTwoTone twoToneColor="red" style={{ fontSize: "2em" }} />
            </Tooltip>
          );
        },
        // sorter: (a, b) => a.name.localeCompare(b.name),
      },
      {
        title: this.props.t("COURSE_TABLE_FLAG"),
        dataIndex: "name",
        key: "name",
        align: "center",
        width: "5vw",
        render: (text, row) => (
          <div>
            <img
              src={process.env.REACT_APP_API_URL + row.language.flagURL}
              alt={row.language.name}
              className="logo-icon"
              style={{ maxHeight: "2vh" }}
            />
          </div>
        ),
        // sorter: (a, b) => a.name.localeCompare(b.name),
      },

      {
        title: this.props.t("COURSE_TABLE_NAME"),
        dataIndex: "name",
        key: "name",

        sortOrder: sortedInfo.columnKey === "name" && sortedInfo.order,
        sorter: (a, b) => a.name.localeCompare(b.name),
      },
      {
        title: this.props.t("COURSE_TABLE_FILE_SIZE"),
        dataIndex: "dataSize",
        key: "dataSize",
        render: (text, row) => <div>{row.dataSize} MB</div>,
      },
      {
        title: this.props.t("COURSE_TABLE_CREATED"),
        dataIndex: "created",
        key: "created",
        sorter: (a, b) => moment(a.created).unix() - moment(b.created).unix(),
        sortOrder: sortedInfo.columnKey === "created" && sortedInfo.order,
        render: (created) => {
          const actualCreated = new Date(created * 1000);
          return <div>{actualCreated.toLocaleDateString()}</div>;
        },
      },
      {
        title: this.props.t("COURSE_TABLE_EDITED"),
        dataIndex: "modified",
        key: "modified",
        sorter: (a, b) => moment(a.modified).unix() - moment(b.modified).unix(),
        sortOrder: sortedInfo.columnKey === "modified" && sortedInfo.order,
        render: (modified) => {
          const actualModified = new Date(modified * 1000);
          return <div>{actualModified.toLocaleDateString()}</div>;
        },
      },
      {
        title: this.props.t("COURSE_TABLE_SHOW_DATA"),
        key: "showData",
        width: "5vw",
        align: "center",
        render: (text, row) => (
          <Button
            onClick={() => this.selectRow(row)}
            shape="circle"
            icon={<EyeOutlined />}
          ></Button>
        ),
      },
      {
        title: this.props.t("COURSE_TABLE_ACTIVE"),
        key: "isActive",
        width: "10vw",
        align: "center",
        sorter: (a, b) => a.isActive - b.isActive,

        sortOrder: sortedInfo.columnKey === "isActive" && sortedInfo.order,
        render: (text, row) => (
          <Space size="middle">
            <Switch
              checked={row.isActive}
              onChange={() => this.isActiveChange(row)}
            />
            {/* {row.isTestable === true ? <CheckCircleOutlined style={{ color: "green" }} /> : <CloseCircleOutlined style={{ color: "red" }} />} */}
          </Space>
        ),
      },
      {
        title: this.props.t("COURSE_TABLE_DELETE"),
        key: "delete",
        width: "5vw",
        align: "center",
        render: (a, row) => (
          <Popconfirm
            title={this.props.t("COURSE_CONFIRM_DELETE_TITLE")}
            onConfirm={() => this.deleteRow(row)}
            onCancel={() => this.cancelDelete(row)}
            okText={this.props.t("CONFIRM_YES")}
            cancelText={this.props.t("CONFIRM_NO")}
          >
            <Button shape="circle" icon={<DeleteOutlined />}></Button>
          </Popconfirm>
        ),
      },
      {
        title: this.props.t("COURSE_TABLE_DUPLICATE"),
        key: "delete",
        width: "5vw",
        align: "center",
        render: (a, row) => (
          <Popconfirm
            title={this.props.t("COURSE_DUPLICATE_TITLE")}
            onConfirm={() => this.duplicateRow(row)}
            onCancel={() => this.cancelDuplicate(row)}
            okText={this.props.t("CONFIRM_YES")}
            cancelText={this.props.t("CONFIRM_NO")}
          >
            <Button shape="circle" icon={<ApartmentOutlined />}></Button>
          </Popconfirm>
        ),
      },
      {
        title: this.props.t("COURSE_TABLE_OWNER"),
        key: "owner",
        dataIndex: "owner",
        // width: "5vw",
        align: "center",
        ...this.getColumnSearchProps("owner"),
        sortOrder: sortedInfo.columnKey === "owner" && sortedInfo.order,
        sorter: (a, b) => a.owner.localeCompare(b.owner),
        // render: (a, row) => <div>{row.owner}</div>,
      },
    ];
    return (
      <React.Fragment>
        <Row>
          <h1>{this.props.t("COURSE_TITLE")}</h1>
        </Row>
        <Row gutter={[24, 24]}>
          {/* <Col span={24}>
            <Button onClick={this.createNewCourse}>
              {this.props.t("COURSE_NEW_COURSE")}
            </Button>
          </Col> */}
          <Col span={24}>
            <Button
              disabled={!this.state.courseActive}
              onClick={this.openNewCourseInNewTab}
            >
              {this.props.t("COURSE_NEW_COURSE")}
            </Button>
          </Col>
        </Row>
        <Row gutter={[24, 24]}>
          {/* <Col span={24} style={{ display: "flex", justifyContent: "flex-end" }}>
                    <Button className="new-user-button" onClick={this.handleClickOnAddNewUser}>Új felhasználó</Button>
                </Col> */}
          <Col span={24}>
            <Table
              size="middle"
              onChange={this.handleChangeTable}
              pagination={{
                position: ["bottomCenter"],
                pageSize: this.state.pageSize,
                current: this.state.current,
              }}
              // pagination={{ position: ["bottomCenter"], pageSize: 10 }}
              rowKey="id"
              // rowSelection={rowSelection}
              columns={columns}
              dataSource={this.props.courses}
              scroll={{ y: "75vh" }}
            ></Table>
          </Col>
        </Row>
        <Drawer
          width={"92%"}
          destroyOnClose={true}
          visible={this.state.courseEditorOpen}
          title={this.props.t("DRAWER_COURSE_EDIT_TITLE")}
          onCancel={this.closeCourseEditor}
          onClose={this.closeCourseEditor}
          maskClosable={false}
          footer={
            <div>
              <Button onClick={this.closeCourseEditor}>Mégsem</Button>
            </div>
          }
        >
          <UnityWebBLCourseEditor />
        </Drawer>
        <Drawer
          width={"92%"}
          destroyOnClose={true}
          visible={this.state.courseDataSheetOpen}
          title={
            this.props.t("DRAWER_COURSE_DATA_SHEET_TITLE") +
            ": " +
            (this.state.actualCourse.course
              ? this.state.actualCourse.course.name.toUpperCase()
              : null)
          }
          onCancel={this.closeCourseDataSheet}
          onClose={this.closeCourseDataSheet}
          maskClosable={false}
          // footer={
          //     <div>
          //         <Button onClick={this.closeCourseDataSheet}>
          //             Mégsem
          //         </Button>
          //     </div>
          // }
        >
          <CourseDataSheet
            courseId={this.state.selectedCourseId}
            setCourse={this.setCourse}
          />
        </Drawer>

        <Drawer
          width={"92%"}
          destroyOnClose={true}
          visible={this.state.createNewCourse}
          title={this.props.t("DRAWER_COURSE_DATA_SHEET_TITLE")}
          onCancel={this.closeCreateNewCourse}
          onClose={this.closeCreateNewCourse}
          maskClosable={false}
          footer={
            <div>
              <Button onClick={this.closeCreateNewCourse}>Mégsem</Button>
            </div>
          }
        >
          <UnityWebBLCourseEditor />
        </Drawer>
      </React.Fragment>
    );
  }
}
const mapStateToProps = (state) => ({
  courses: state.courseReducer.courses,
  deleteStatus: state.courseReducer.deleteStatus,
  isActive: state.unityReducer.isActive,
  sortedInfo: state.filterReducer.sortedInfoBaseCourse,
  searchOptionsCourseBase: state.filterReducer.searchOptionsCourseBase,
  currentBaseCourseTab: state.tabHelperReducer.currentBaseCourseTab,
});
const Landing = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedLanding)
);

export default Landing;
