import React, { Component } from "react";
import Body from "./body";
import { Layout, Spin, Row, Col, Button } from "antd";
import { Menu } from "antd";
import {
  PieChartOutlined, TeamOutlined, UserOutlined,
} from "@ant-design/icons";
import "./main.scss";
import { NavLink } from "react-router-dom";
import { logout } from "../../actions/login";
import { connect } from "react-redux";
import Cookies from "universal-cookie";
import SubMenu from "antd/lib/menu/SubMenu";
import { withTranslation } from "react-i18next";


const { Header, Sider, Content } = Layout;

const mapDispatch = (dispatch) => {
  return {
    logout: () => dispatch(logout()),
  };
};

class ConnectedMain extends Component {
  state = {
    collapsed: false,
    selectedKey: null,
  };

  componentDidMount = () => {
    // window.onbeforeunload = function () {
    //   localStorage.clear();
    // }
    this.setDefaultSelectedKeyForMenu();
  };



  handleMenuClick = async () => {

        await this.props.logout();
        this.props.history.push("/welcome");
        const cookies = new Cookies();
        cookies.remove("token");
        cookies.remove("userId");

  };

  setDefaultSelectedKeyForMenu = () => {
    this.setState({ selectedKey: "1" });
  };

  handleSelect = (event) => {
    this.setState({ selectedKey: event.key });
  };

  toggle = () => {
    this.setState({
      collapsed: !this.state.collapsed,
    });
  };

  clikcOnShowUserData = () => {
    this.props.history.push("/vrtanoda/user")
  }


  render() {
    return (
      <Spin
        spinning={false}
        className="customSpin"
        style={{
          zIndex: 100000000,
        }}
        size="large"
      >
        <div style={{ height: "100%" }}>
          <Layout className="site-layout" style={{ height: "10vh" }}>
            <Header
              className="site-layout-background"
              style={{ padding: "0px", height: "100%" }}
            >
              <Row align="middle" justify="center">
                <Col
                  span={4}
                  style={{
                    alignItems: "center",
                    justifyContent: "flex-start",
                    display: "flex",
                  }}
                >
                  {/* {this.props.user.groupId === 1 ? <img src={logoTM} alt="teva logo" className="logo-icon" style={{ maxHeight: "5vh", paddingLeft: "1em" }} />
                    :
                    <img src={logoDSM} alt="teva logo" className="logo-icon" style={{ maxHeight: "5vh", paddingLeft: "1em" }} />
                  } */}
                </Col>
                {/* <Col span={16} style={{ alignItems: "center", justifyContent: "center", display: "flex" }}><h2 style={{ color: "#00A03B" }}> {this.props.headerActualRouteName + this.props.customString}</h2></Col> */}
                <Col
                  span={20}
                  style={{
                    alignItems: "center",
                    justifyContent: "flex-end",
                    display: "flex",
                  }}
                >
                  <div style={{ marginRight: "1em" }}>
                    <p>
                      {this.props.t("MENU_WELCOME")}{" "}
                      <strong>{this.props.user.firstName + " "+ this.props.user.lastName}</strong>
                      <Button
                        style={{ marginLeft: "1em" }}
                        icon={<UserOutlined />}
                        onClick={this.clikcOnShowUserData}
                      ></Button>
                    </p>
                  </div>
                </Col>
              </Row>
            </Header>
          </Layout>
          <Layout
            style={{
              height: "90vh",
            }}
          >
            <Sider trigger={null} collapsible collapsed={this.state.collapsed}>
              <Menu
                style={{ height: "80vh" }}
                theme="dark"
                mode="inline"
                selectedKeys={[this.state.selectedKey]}
                onSelect={this.handleSelect}
              >
                {/* admin */}

                <Menu.Item key="1" icon={<PieChartOutlined />}>
                  <NavLink to="/vrtanoda/landing" className="link-color">
                    {this.props.t("MENU_COURSE")}
                  </NavLink>
                </Menu.Item>
                {(this.props.user.groupId === 1 ||
                  this.props.user.groupId === 2) && (
                  <SubMenu
                    key="sub1"
                    icon={<TeamOutlined />}
                    title="Felhasználó kezelés"
                  >
                    <Menu.Item key="5">
                      <NavLink to="/vrtanoda/user-list" className="link-color">
                        {this.props.t("MENU_USERS")}
                      </NavLink>
                    </Menu.Item>
                    {this.props.user.groupId === 1 && (
                      <Menu.Item key="6">
                        <NavLink
                          to="/vrtanoda/admin-list"
                          className="link-color"
                        >
                          {this.props.t("MENU_ADMINS")}
                        </NavLink>
                      </Menu.Item>
                    )}
                    {this.props.user.groupId === 1 && (
                      <Menu.Item key="7">
                        <NavLink
                          to="/vrtanoda/trainer-list"
                          className="link-color"
                        >
                          {this.props.t("MENU_MAINTAINER")}
                        </NavLink>
                      </Menu.Item>
                    )}
                  </SubMenu>
                )}
                <Menu.Item key="2" icon={<PieChartOutlined />}>
                  <NavLink to="/vrtanoda/file-manager" className="link-color">
                    {this.props.t("MENU_FILE_MANAGER")}
                  </NavLink>
                </Menu.Item>
                <Menu.Item key="3" icon={<PieChartOutlined />}>
                  <NavLink
                    to="/vrtanoda/quality-control"
                    className="link-color"
                  >
                    {this.props.t("MENU_QUALITY_CONTROL")}
                  </NavLink>
                </Menu.Item>
                <Menu.Item key="8" icon={<PieChartOutlined />}>
                  <NavLink
                    to="/vrtanoda/digittal-twin-control"
                    className="link-color"
                  >
                    {this.props.t("MENU_DIGITAL_TWIN_CONTROL")}
                  </NavLink>
                </Menu.Item>
              </Menu>
              <Row justify="center" align="middle">
                <Button onClick={this.handleMenuClick}>
                  {this.props.t("MENU_LOGOUT")}
                </Button>
              </Row>
            </Sider>
            <Layout className="site-layout">
              <Content
                className="site-layout-background"
                style={{
                  margin: "24px 16px",
                  padding: 24,
                  height: "100%",
                  //minHeight: 500,
                }}
              >
                <Body />
              </Content>
            </Layout>
          </Layout>
        </div>
      </Spin>
    );
  }
}

const mapState = (state) => {
  return {
    user: state.loginReducer.user,

  };
};

const Main = withTranslation()(connect(mapState, mapDispatch)(ConnectedMain));
export default Main;