import React, { Component } from "react";
import { connect } from "react-redux";
import { Row, Input, Col, Button, notification, DatePicker } from "antd";
import { getUserById, modifyAdminAndTrainer } from "../../../actions/user";
import { withTranslation } from "react-i18next";
import moment from "moment";

const mapDispatchToProps = (dispatch) => {
  return {
    getUserById: (userId) => dispatch(getUserById(userId)),
    modifyAdmin: (sendObj) => dispatch(modifyAdminAndTrainer(sendObj)),
  };
};

const strongRegex = new RegExp("^(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.{8,})");
// const mediumRegex = new RegExp("^(((?=.*[a-z])(?=.*[A-Z]))|((?=.*[a-z])(?=.*[0-9]))|((?=.*[A-Z])(?=.*[0-9])))(?=.{6,})");

class ConnectedAdminUser extends Component {
  state = {
    newPasswordIsStrong: false,
    newPassword: "",
    repeatedNewPassword: "",
    firstName: "",
    lastName: "",
    email: "",
    rank: "",
    formValid: false,
    groupId: 3,
    workStartDate: null,
  };

  componentDidMount = async () => {
    const splietted = this.props.location.pathname.split("/");
    await this.props.getUserById(splietted[3]);
    this.setState({
      firstName: this.props.user.firstName,
      lastName: this.props.user.lastName,
      email: this.props.user.email,
      groupId: this.props.user.groupId,
      rank: this.props.user.rank,
      workStartDate: this.props.user.workStartDate,
    });
  };

  analyzeNewPassword = (event) => {
    const actualValue = event.target.value;
    this.setState({ newPassword: actualValue });
    if (strongRegex.test(actualValue)) {
      this.setState({ newPasswordIsStrong: true });
    } else {
      this.setState({ newPasswordIsStrong: false });
    }
  };

  handleChangeRepeatedPassword = (event) => {
    const actualValue = event.target.value;
    this.setState({ repeatedNewPassword: actualValue });
  };

  handleChangeFirstName = (event) => {
    const actualValue = event.target.value;
    this.setState({ firstName: actualValue });
  };
  handleChangeLastName = (event) => {
    const actualValue = event.target.value;
    this.setState({ lastName: actualValue });
  };

  handleChangeRank = (event) => {
    const actualValue = event.target.value;
    this.setState({ rank: actualValue });
  };
  onChangeDate = (value) => {
    this.setState({ workStartDate: Math.round(value / 1000) });
  };

  saveEditedUserData = async () => {
    const saveObj = {
      id: this.props.user.id,
      email: this.props.user.email,
      password: this.state.newPassword,
      firstName: this.state.firstName,
      lastName: this.state.lastName,
      rank: this.state.rank,
      workStartDate: this.state.workStartDate,
    };
    await this.props.modifyAdmin(saveObj);
    if (this.props.modifyAdminStatus === "sended") {
      notification["success"]({
        message: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_OK_TITLE"),
        description: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_OK_DESC"),
      });
      this.props.history.push("/vrtanoda/user-list");
    } else {
      notification["error"]({
        message: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_ERROR_TITLE"),
        description: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_ERROR_DESC"),
      });
    }
  };

  formChecker = async () => {
    if (!this.state.firstName || this.state.firstName.trim() === "") {
      notification["error"]({
        message: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_ERROR_TITLE"),
        description: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_ERROR_DESC_1"),
        onClick: () => {
        },
      });
    } else if (!this.state.lastName || this.state.lastName.trim() === "") {
      notification["error"]({
        message: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_ERROR_TITLE"),
        description: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_ERROR_DESC_1"),
        onClick: () => {
        },
      });
    } else if (
      this.state.newPassword.trim() !== "" &&
      this.state.newPasswordIsStrong !== true
    ) {
      notification["error"]({
        message: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_ERROR_TITLE"),
        description: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_ERROR_DESC_2"),
        onClick: () => {
        },
      });
    } else if (
      this.state.newPassword.trim() !== "" &&
      this.state.newPassword !== this.state.repeatedNewPassword
    ) {
      notification["error"]({
        message: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_ERROR_TITLE"),
        description: this.props.t("EDIT_ADMIN_NOTIFICATION_SAVE_ERROR_DESC_3"),
        onClick: () => {
        },
      });
    } else {
      await this.saveEditedUserData();
    }
  };

  render() {
    return (
      <React.Fragment>
        {this.props.user && (
          <Row gutter={[24, 12]}>
            <Col span={6}></Col>
            <Col span={10}>
              <Col span={24}>{this.props.t("EDIT_ADMIN_FIRST_NAME")}:</Col>
              <Col span={24}>
                <Input
                  value={this.state.firstName}
                  onChange={this.handleChangeFirstName}
                ></Input>
              </Col>
              <Col span={24}>{this.props.t("EDIT_ADMIN_LAST_NAME")}:</Col>
              <Col span={24}>
                <Input
                  value={this.state.lastName}
                  onChange={this.handleChangeLastName}
                ></Input>
              </Col>
              <Col span={24}>{this.props.t("EDIT_ADMIN_RANK")}:</Col>
              <Col span={24}>
                <Input
                  value={this.state.rank}
                  onChange={this.handleChangeRank}
                ></Input>
              </Col>
              <Col span={24}>{this.props.t("EDIT_ADMIN_E_MAIL")}:</Col>
              <Col span={24}>
                <Input value={this.state.email} disabled={true}></Input>
              </Col>

              <Col span={24}>{this.props.t("NEW_USER_WORK_START_DATE")}:</Col>
              <Col span={24}>
                <DatePicker
                  value={moment(this.state.workStartDate * 1000)}
                  onChange={this.onChangeDate}
                />
              </Col>

              <Col span={24}>{this.props.t("EDIT_ADMIN_NEW_PASSWORD")}:</Col>
              <Col span={24}>
                <Input.Password
                  placeholder="Minnimum 8 karakter, kis- és nagybetű, szám"
                  onChange={this.analyzeNewPassword}
                />
              </Col>
              <Col span={24}>
                {this.props.t("EDIT_ADMIN_NEW_PASSWORD_AGAIN")}:
              </Col>
              <Col span={24}>
                <Input.Password
                  placeholder="Új jelszó újra"
                  onChange={this.handleChangeRepeatedPassword}
                ></Input.Password>
              </Col>
              <Col span={24}></Col>
              <Col
                span={24}
                style={{
                  display: "flex",
                  alignItems: "center",
                  justifyContent: "center",
                  paddingTop: "2em",
                }}
              >
                <Button
                  className="save-new-pharmacy-button"
                  type="primary"
                  onClick={this.formChecker}
                >
                  {this.props.t("EDIT_ADMIN_SAVE_BUTTON")}
                </Button>
              </Col>
            </Col>
            <Col span={6}></Col>
          </Row>
        )}
      </React.Fragment>
    );
  }
}
const mapStateToProps = (state) => ({
  user: state.userReducer.user,
  loggedInUser: state.loginReducer.user,
  modifyAdminStatus: state.userReducer.modifyAdminStatus,
});
const EditAdmin = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedAdminUser)
);
export default EditAdmin;
