import React, { Component } from "react";
import { connect } from "react-redux";
import {
  Col,
  Row,
  Button,
  Input,
  notification,
  Popconfirm,
  DatePicker,
  Select,
} from "antd";
import { getNewCode, editUser, getUserById } from "../../../actions/user";
import { DeleteTwoTone } from "@ant-design/icons";
import { v4 as uuidv4 } from "uuid";
import moment from "moment";
import { withTranslation } from "react-i18next";
const { Option } = Select;
const mapDispatchToProps = (dispatch) => {
  return {
    getNewCode: () => dispatch(getNewCode()),
    editUser: (saveObj) => dispatch(editUser(saveObj)),
    getUserById: (userId) => dispatch(getUserById(userId)),
  };
};
class ConnectedEditUser extends Component {
  state = {
    firstName: "",
    lastName: "",
    organizationalUnit: "",
    workGroup: "",
    groupId: 3,
    workStartDate: 1594512000,
    birthDate: 1594512000,
    uniquefileds: [],
    gender: [
      {
        id: 1,
        value: "Férfi",
      },
      {
        id: 2,
        value: "Nő",
      },
      {
        id: 3,
        value: "Egyéb",
      },
    ],
    selectedGender: {
      id: 1,
      value: "Férfi",
    },
    generatedID: "",
  };
  componentDidMount = async () => {
    await this.props.getNewCode();
    const splietted = this.props.location.pathname.split("/");

    await this.props.getUserById(splietted[3]);
    const filteredGender = this.state.gender.filter(
      (item) => item.value === this.props.user.genderIdentity
    );
    let _tempArray = [];
    if (
      this.props.user.userUniqueField &&
      this.props.user.userUniqueField.length > 0
    ) {
      for (
        let index = 0;
        index < this.props.user.userUniqueField.length;
        index++
      ) {
        const element = this.props.user.userUniqueField[index];
        const newRow = {
          key: element.id,
          value: element.value,
        };
        _tempArray = [..._tempArray, newRow];
      }
    }
    this.setState({
      firstName: this.props.user.firstName,
      lastName: this.props.user.lastName,
      birthDate: this.props.user.birthDate,
      selectedGender: filteredGender[0]
        ? filteredGender[0]
        : this.state.selectedGender,
      organizationalUnit: this.props.user.organizationalUnit,
      workGroup: this.props.user.jobGroup,
      workStartDate: this.props.user.workStartDate,
      generatedID: this.props.user.generatedID,
      uniquefileds: _tempArray,
    });
  };
  changeLastName = (event) => {
    const act = event.target.value;
    this.setState({ lastName: act });
  };
  changeFirstName = (event) => {
    const act = event.target.value;
    this.setState({ firstName: act });
  };
  changeOrganizationalUnit = (event) => {
    const act = event.target.value;
    this.setState({ organizationalUnit: act });
  };
  changeWorkGroup = (event) => {
    const act = event.target.value;
    this.setState({ workGroup: act });
  };
  addNewUniqueValue = () => {
    const key = uuidv4();
    if (this.state.uniquefileds.length + 1 > 10) {
      notification["info"]({
        message: this.props.t("NEW_USER_UNIQUE_FIELD_LIMIT_TITLE"),
        description: this.props.t("NEW_USER_UNIQUE_FIELD_LIMIT_DESC"),
      });
    } else {
      const newRow = {
        key: key,
        value: "",
      };
      const newunique = [...this.state.uniquefileds, newRow];
      this.setState({ uniquefileds: newunique });
    }
  };
  deleteUniqueField = (row) => {
    const filtered = this.state.uniquefileds.filter(
      (item) => item.key !== row.key
    );
    this.setState({ uniquefileds: filtered });
  };
  changeUniquevalue = (i, event) => {
    const actValue = event.target.value;
    const _temp = this.state.uniquefileds;
    _temp[i].value = actValue;
    this.setState({ uniquefileds: _temp });
  };
  selectGender = (event) => {
    const filteredTypes = this.state.gender.filter(
      (item) => item.value === event
    );
    this.setState({ selectedGender: filteredTypes[0] });
  };
  onChangeDate = (value) => {
    const _date = value.unix();
    this.setState({ workStartDate: _date });
  };

  saveEditedUser = async () => {
    if (!this.state.firstName || this.state.firstName.trim() === "") {
      notification["error"]({
        message: "Név",
        description: "A tanuló neve nem maradhat üresen.",
      });
    } else if (!this.state.lastName || this.state.lastName.trim() === "") {
      notification["error"]({
        message: "Név",
        description: "A tanuló neve nem maradhat üresen.",
      });
    } else if (!this.state.birthDate || this.state.birthDate === "") {
      notification["error"]({
        message: "Születési idő",
        description: "A születési idő nem maradhat üresen.",
      });
    } else if (!this.state.gender || this.state.gender === "") {
      notification["error"]({
        message: "Nemi identitás",
        description: "A tanuló nemi identitása nem maradhat üresen.",
      });
    } else if (!this.state.workStartDate || this.state.workStartDate === "") {
      notification["error"]({
        message: this.props.t("NEW_USER_WORK_START_DATE_TITLE"),
        description: this.props.t("NEW_USER_WORK_START_DATE_DESC"),
      });
    } else if (
      !this.state.organizationalUnit ||
      this.state.organizationalUnit.trim() === ""
    ) {
      notification["error"]({
        message: this.props.t("NEW_USER_ORGANIZATION_UNIT_TITLE"),
        description: this.props.t("NEW_USER_ORGANIZATION_UNIT_DESC"),
      });
    } else if (!this.state.workGroup || this.state.workGroup.trim() === "") {
      notification["error"]({
        message: this.props.t("NEW_USER_WORK_GROUP_TITLE"),
        description: this.props.t("NEW_USER_WORK_GROUP_DESC"),
      });
    } else {
      let error = false;
      if (this.state.uniquefileds.length > 0) {
        for (let index = 0; index < this.state.uniquefileds.length; index++) {
          const element = this.state.uniquefileds[index];
          if (element.value.trim() === "") {
            error = true;
          }
        }
        if (error === true) {
          notification["error"]({
            message: this.props.t("NEW_USER_UNIQUE_FIELD_TITLE"),
            description: this.props.t("NEW_USER_UNIQUE_FIELD_DESC"),
          });
        }
      }
      const saveObj = {
        userId: this.props.user.id,
        userCode: this.state.userCode,
        firstName: this.state.firstName,
        lastName: this.state.lastName,
        birthDate: this.state.birthDate,
        workGroup: this.state.workGroup,
        organizationalUnit: this.state.organizationalUnit,
        gender: this.state.selectedGender.value,
        workStartDate: this.state.workStartDate,
        uniquefileds: this.state.uniquefileds,
      };
      if (error === false) {
        await this.props.editUser(saveObj);
        if (this.props.addUserStatus && this.props.addUserStatus === "sended") {
          this.props.history.push("/vrtanoda/user-list");
          notification["success"]({
            message: this.props.t("NEW_USER_SAVE_SUCCESS_TITLE"),
            description: this.props.t("NEW_USER_SAVE_SUCCESS_DESC"),
          });
        }
        if (this.props.addUserStatus && this.props.addUserStatus === "error") {
          if (this.props.code === 1004) {
            notification["error"]({
              message: this.props.t("NEW_USER_SAVE_ERROR_TITLE"),
              description: this.props.t("NEW_USER_SAVE_ERROR_DESC"),
            });
          } else {
            notification["error"]({
              message: this.props.t("NEW_USER_SAVE_ERROR_TITLE_2"),
              description: this.props.t("NEW_USER_SAVE_ERROR_DESC_2"),
            });
          }
        }
      }
    }
  };
  onChangeBirthDate = (date, dateString) => {
    const actualDate = new Date().getUTCFullYear();
    if (dateString > actualDate) {
      notification["error"]({
        message: this.props.t("NEW_USER_DATE_ERROR_TITLE"),
        description: this.props.t("NEW_USER_DATE_ERROR_DESC"),
      });
    } else {
      const _date = date.unix();
      this.setState({ birthDate: _date });
    }
  };
  render() {
    return (
      <React.Fragment>
        <Row gutter={[24, 12]}>
          <Col span={24}>
            <Button
              className="save-new-pharmacy-button"
              type="primary"
              onClick={this.saveEditedUser}
            >
              {this.props.t("NEW_USER_SAVE")}
            </Button>
          </Col>
        </Row>
        <Row gutter={[24, 12]} justify="center" align="middle">
          <Col span={12}>
            {this.props.userCode && (
              <Row gutter={[24, 12]}>
                <Col span={6}>{this.props.t("NEW_USER_ID")}:</Col>
                <Col span={18}>
                  <Input disabled={true} value={this.state.generatedID}></Input>
                </Col>
              </Row>
            )}
            <Row gutter={[24, 12]}>
              <Col span={6}>{this.props.t("NEW_USER_NAME_FIRSTNAME")}:</Col>
              <Col span={18}>
                <Input
                  onChange={this.changeFirstName}
                  value={this.state.firstName}
                ></Input>
              </Col>
            </Row>
            <Row gutter={[24, 12]}>
              <Col span={6}>{this.props.t("NEW_USER_NAME_LASTNAME")}:</Col>
              <Col span={18}>
                <Input
                  onChange={this.changeLastName}
                  value={this.state.lastName}
                ></Input>
              </Col>
            </Row>
            <Row gutter={[24, 12]}>
              <Col span={6}>{this.props.t("NEW_USER_BIRTH_DATE")}:</Col>
              <Col span={18}>
                <DatePicker
                  value={moment(this.state.birthDate * 1000)}
                  onChange={this.onChangeBirthDate}
                  picker="year"
                />
              </Col>
            </Row>
            <Row gutter={[24, 12]}>
              <Col span={6}>{this.props.t("NEW_USER_GENDER")}:</Col>
              <Col span={18}>
                <Select
                  value={this.state.selectedGender.value}
                  style={{ width: 120 }}
                  onSelect={this.selectGender}
                >
                  {this.state.gender.map((item) => {
                    return (
                      <Option value={item.value} key={item.key}>
                        {item.value}
                      </Option>
                    );
                  })}
                </Select>
              </Col>
            </Row>
            <Row gutter={[24, 12]}>
              <Col span={6}>{this.props.t("NEW_USER_WORK_START_DATE")}:</Col>
              <Col span={18}>
                <DatePicker
                  value={moment(this.state.workStartDate * 1000)}
                  onChange={this.onChangeDate}
                />
              </Col>
            </Row>
            <Row gutter={[24, 12]}>
              <Col span={6}>{this.props.t("NEW_USER_ORGANIZTAION_UNIT")}:</Col>
              <Col span={18}>
                <Input
                  onChange={this.changeOrganizationalUnit}
                  value={this.state.organizationalUnit}
                ></Input>
              </Col>
            </Row>
            <Row gutter={[24, 12]}>
              <Col span={6}>{this.props.t("NEW_USER_WORK_GROUP")}:</Col>
              <Col span={18}>
                <Input
                  onChange={this.changeWorkGroup}
                  value={this.state.workGroup}
                ></Input>
              </Col>
            </Row>

            {this.state.uniquefileds.map((item, i) => {
              return (
                <Row gutter={[24, 12]}>
                  <Col span={6}>
                    {this.props.t("NEW_USER_UNIQUE_FIELD")} {i + 1}
                  </Col>
                  <Col span={16}>
                    <Input
                      onChange={(event) => this.changeUniquevalue(i, event)}
                      value={item.value}
                    ></Input>
                  </Col>
                  <Col span={2}>
                    <Popconfirm
                      title="Biztosan törölni akarja az egyedi mezőt?"
                      okText="Igen"
                      cancelText="Nem"
                      onConfirm={() => this.deleteUniqueField(item)}
                    >
                      <Button shape="circle" icon={<DeleteTwoTone />} />
                    </Popconfirm>
                  </Col>
                </Row>
              );
            })}
            <Row gutter={[24, 12]} align="middle" justify="center">
              <Button type="primary" onClick={() => this.addNewUniqueValue()}>
                {this.props.t("NEW_USER_ADD_NEW")}
              </Button>
            </Row>
          </Col>
        </Row>
      </React.Fragment>
    );
  }
}
const mapStateToProps = (state) => ({
  user: state.userReducer.user,
  newUserSaveStatus: state.userReducer.newUserSaveStatus,
  loggedInUser: state.loginReducer.user,
  userCode: state.userReducer.userCode,
  addUserStatus: state.userReducer.addUserStatus,
  code: state.userReducer.code,
});
const EditUser = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedEditUser)
);
export default EditUser;
