import React, { Component } from "react";
import { connect } from "react-redux";
import { Row, Col, Table, Button, notification, Checkbox, Drawer } from "antd";
import {
  deleteUsersByIds,
  deactivateAndActivateUsersById,
  getAllPlayer,
} from "../../../actions/user";
// import { setFilter } from '../../actions/filter';
import { EditOutlined, EyeOutlined } from "@ant-design/icons";
import { withTranslation } from "react-i18next";
import UserCourse from "../user-courses"

const mapDispatchToProps = (dispatch) => {
  return {
    getAllPlayer: () => dispatch(getAllPlayer()),
    deleteUsersByIds: (ids) => dispatch(deleteUsersByIds(ids)),
    deactivateAndActivateUsersById: (userId) =>
      dispatch(deactivateAndActivateUsersById(userId)),
  };
};

class ConnectedUserList extends Component {
  state = {
    deleteButtonIsActive: true,
    selectedRowKeys: [],
    columns: [
      {
        title: this.props.t("USER_LIST_TABLE_NAME"),
        dataIndex: "name",
        key: "name",
        sorter: (a, b) => a.name.localeCompare(b.name),
      },
      {
        title: this.props.t("USER_LIST_TABLE_EMAIL"),
        dataIndex: "email",
        key: "email",
      },
      {
        title: this.props.t("USER_LIST_TABLE_RIGHTS"),
        dataIndex: "group",
        key: "group",
        // sorter: (a, b) => a.group.localeCompare(b.group)
      },
      {
        title: this.props.t("USER_LIST_TABLE_EDIT"),
        key: "showData",
        width: "5vw",
        align: "center",
        render: (text, row) => (
          <Button
            onClick={() => this.selectRow(row)}
            shape="circle"
            icon={<EditOutlined />}
          ></Button>
        ),
      },
      {
        title: this.props.t("USER_LIST_TABLE_ISACTIVE"),
        dataIndex: "isActive",
        key: "isActive",
        width: "8vw",
        align: "center",
        sorter: (a, b) => a.isActive - b.isActive,
        render: (text, row) => (
          <Checkbox
            onChange={() => this.changeIsActive(row)}
            checked={row.isActive}
          />
        ),
      },
      {
        title: this.props.t("USER_LIST_TABLE_EDIT_COURSE"),
        key: "showData",
        width: "5vw",
        align: "center",
        render: (text, row) => (
          <Button
            onClick={() => this.showUserCourses(row)}
            shape="circle"
            icon={<EyeOutlined />}
          ></Button>
        ),
      },
    ],
    courseEditorOpen: false,
    userId: null
  };

  componentDidMount = async () => {
    await this.props.getAllPlayer();
  };

  changeIsActive = async (row) => {
    if (this.props.user && this.props.user.group.id === 1) {
      await this.props.deactivateAndActivateUsersById(row.id);
      await this.props.getAllPlayer();
    } else {
      notification["warning"]({
        message: this.props.t("USER_LIST_RIGHTS_PROBLEM_TITLE"),
        description: this.props.t("USER_LIST_RIGHTS_PROBLEM_DESC"),
      });
    }
  };

  handleClickOnAddNewUser = () => {
    this.props.history.push("/vrtanoda/new-user");
  };

  selectRow = async (record) => {
    this.props.history.push("/vrtanoda/edit-user/" + record.id);
  };

  handleDeleteSelectedRows = async () => {
    this.setState({ deleteButtonIsActive: false });
    if (this.state.selectedRowKeys && this.state.selectedRowKeys.length > 0) {
      const sendDeletedIds = {
        ids: this.state.selectedRowKeys,
      };
      await this.props.deleteUsersByIds(sendDeletedIds);
      if (
        this.props.usersDeleteStatus &&
        this.props.usersDeleteStatus === "deleted"
      ) {
        this.setState({ selectedRowKeys: [] });
        notification["success"]({
          message: this.props.t("USER_LIST_DELETE_SUCCESS_TITLE"),
          description: this.props.t("USER_LIST_DELETE_SUCCESS_DESC"),
        });
      } else {
        notification["error"]({
          message: this.props.t("USER_LIST_DELETE_ERROR_TITLE_1"),
          description: this.props.t("USER_LIST_DELETE_ERROR_DESC_1"),
        });
      }
    } else {
      notification["error"]({
        message: this.props.t("USER_LIST_DELETE_ERROR_TITLE_2"),
        description: this.props.t("USER_LIST_DELETE_ERROR_DESC_2"),
      });
    }
    this.setState({ deleteButtonIsActive: true });
    await this.props.getAllPlayer();
  };

  onSelectChange = (selectedRowKeys) => {
    this.setState({ selectedRowKeys });
  };
  showUserCourses = (row) => {
    console.log(row);

    this.setState({ userId: row.id, courseEditorOpen: true });
  };
  closeUserCourse = () => {
    this.setState({ courseEditorOpen: false });
  };
  render() {
    return (
      <div>
        <h1 style={{ fontFamily: "none" }}>
          <Row gutter={[24, 24]}>
            <Col
              span={24}
              style={{ display: "flex", justifyContent: "flex-end" }}
            >
              <Button
                className="new-user-button"
                onClick={this.handleClickOnAddNewUser}
              >
                {this.props.t("USER_LIST_NEW_USER")}
              </Button>
            </Col>
            <Col span={24}>
              <Table
                size="middle"
                pagination={{ position: ["bottomCenter"], pageSize: 10 }}
                rowKey="id"
                // rowSelection={rowSelection}
                columns={this.state.columns}
                dataSource={this.props.userList}
                scroll={{ y: "75vh" }}
                // onRow={(record, rowIndex) => {
                //     return {
                //         onClick: event => { this.selectRow(record, rowIndex) },
                //         // style: { backgroundColor: rowIndex === this.state.selectedRowKey ? "#e6f3ff" : "" }
                //     };
                // }}
              ></Table>
            </Col>
          </Row>
        </h1>
        <Drawer
          width={"92%"}
          destroyOnClose={true}
          visible={this.state.courseEditorOpen}
          title={this.props.t("DRAWER_COURSE_EDIT_TITLE")}
          onCancel={this.closeUserCourse}
          onClose={this.closeUserCourse}
          maskClosable={false}
          footer={
            <div>
              <Button onClick={this.closeUserCourse}>Mégsem</Button>
            </div>
          }
        >
          <UserCourse userId={this.state.userId} />
        </Drawer>
      </div>
    );
  }
}
const mapStateToProps = (state) => ({
  userList: state.userReducer.players,
  usersDeleteStatus: state.userReducer.usersDeleteStatus,
  user: state.loginReducer.user,
});
const UserList = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedUserList)
);
export default UserList;
