import React, { Component } from 'react';
import { connect } from 'react-redux';
import { Col, Row, Button, Input, notification, DatePicker, } from 'antd';
import moment from "moment"
import { withTranslation } from 'react-i18next';
import { addNewAdminOrTrainer } from '../../../actions/user';
const mapDispatchToProps = (dispatch) => {
    return {
        addNewAdminOrTrainer: (saveObj) => dispatch(addNewAdminOrTrainer(saveObj))
    };
};

const strongRegex = new RegExp("^(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.{8,})");

class ConnectedNewTrainer extends Component {

    state = {
        newPasswordIsStrong: false,
        newPassword: "",
        repeatedNewPassword: "",
        firstName: "",
        lastName: "",
        organizationalUnit: "",
        workGroup: "",
        rank: "",
        email: "",
        workStartDate: new Date() / 1000,

    }

    changeFirstName = (event) => {
        const act = event.target.value
        this.setState({ firstName: act })
    }
    changeLastName = (event) => {
        const act = event.target.value
        this.setState({ lastName: act })
    }
    changerank = (event) => {
        const act = event.target.value
        this.setState({ rank: act })
    }
    changeEmail = (event) => {
        const act = event.target.value
        this.setState({ email: act })
    }

    onChangeDate = (value) => {
        this.setState({ workStartDate: Math.round(value / 1000) })
    }

    analyzeNewPassword = (event) => {
        const actualValue = event.target.value
        this.setState({ newPassword: actualValue })
        if (strongRegex.test(actualValue)) {
            this.setState({ newPasswordIsStrong: true })
        } else {
            this.setState({ newPasswordIsStrong: false })
        }
    }

    handleChangeRepeatedPassword = (event) => {
        const actualValue = event.target.value;
        this.setState({ repeatedNewPassword: actualValue })
    }

    saveEditedAdminOrTrainerData = async () => {
        const saveObj = {
            firstName: this.state.firstName,
            lastName: this.state.lastName,
            rank: this.state.rank,
            email: this.state.email,
            workStartDate: this.state.workStartDate,
            password: this.state.newPassword,
            groupId: 2
        }
        await this.props.addNewAdminOrTrainer(saveObj)
        if (this.props.addAdminOrTrainerStatus && this.props.addAdminOrTrainerStatus === "sended") {
            this.props.history.push("/vrtanoda/trainer-list")
            notification["success"]({
                message: this.props.t('NEW_ADMIN_OR_TRAINER_SAVE_SUCCESS_TITLE'),
                description:
                    this.props.t('NEW_ADMIN_OR_TRAINER_SAVE_SUCCESS_DESC'),
            });
        }
        if (this.props.addAdminOrTrainerStatus && this.props.addAdminOrTrainerStatus === "error") {
            if (this.props.code === 1004) {
                notification["error"]({
                    message: this.props.t('NEW_ADMIN_OR_TRAINER_SAVE_ERROR_TITLE'),
                    description:
                        this.props.t('NEW_ADMIN_OR_TRAINER_SAVE_ERROR_DESC'),
                });
            }
            else if (this.props.code === 10) {
                notification["error"]({
                    message: this.props.t('NEW_ADMIN_EMAIL_FORMAT_TITLE'),
                    description:
                        this.props.t('NEW_ADMIN_EMAIL_FORMAT_DESC'),
                });
            } else {
                notification["error"]({
                    message: this.props.t('NEW_ADMIN_OR_TRAINER_SAVE_ERROR_TITLE_2'),
                    description:
                        this.props.t('NEW_ADMIN_OR_TRAINER_SAVE_ERROR_DESC_2'),
                });
            }
        }
    }

    formChecker = async () => {
        if (!this.state.firstName
            || this.state.firstName.trim() === "") {
            notification["error"]({
                message: this.props.t('EDIT_TRAINER_NOTIFICATION_SAVE_ERROR_TITLE'),
                description:
                    this.props.t('EDIT_TRAINER_NOTIFICATION_SAVE_ERROR_DESC_1'),
            });
        }
        else if (!this.state.lastName
            || this.state.lastName.trim() === "") {
            notification["error"]({
                message: this.props.t('EDIT_TRAINER_NOTIFICATION_SAVE_ERROR_TITLE'),
                description:
                    this.props.t('EDIT_TRAINER_NOTIFICATION_SAVE_ERROR_DESC_1'),
            });
        }
        else if (!this.state.email || this.state.email.trim() === "") {
            notification["error"]({
                message: this.props.t('ADD_ADMIN_EMAIL_MISSING_TITLE'),
                description:
                    this.props.t('ADD_ADMIN_EMAIL_MISSING_DESC'),
            });
        }

        else if (this.state.newPassword.trim() !== "" &&
            this.state.newPasswordIsStrong !== true) {
            notification["error"]({
                message: this.props.t('EDIT_TRAINER_NOTIFICATION_SAVE_ERROR_TITLE'),
                description:
                    this.props.t('EDIT_TRAINER_NOTIFICATION_SAVE_ERROR_DESC_2'),
            });
        }
        else if (
            this.state.newPassword.trim() !== "" && this.state.newPassword !== this.state.repeatedNewPassword) {
            notification["error"]({
                message: this.props.t('EDIT_TRAINER_NOTIFICATION_SAVE_ERROR_TITLE'),
                description:
                    this.props.t('EDIT_TRAINER_NOTIFICATION_SAVE_ERROR_DESC_3'),
            });
        }
        else {
            await this.saveEditedAdminOrTrainerData();
        }
    }
    render() {
        return <React.Fragment>
            <Row gutter={[24, 12]} justify="center" align="middle">
                <Col span={12}>
                    <Row gutter={[24, 12]}>
                        <Col span={6}>
                            {this.props.t('NEW_USER_NAME_FIRSTNAME')}:
                    </Col>
                        <Col span={18}>
                            <Input onChange={this.changeFirstName}></Input>
                        </Col>
                    </Row>
                    <Row gutter={[24, 12]}>
                        <Col span={6}>
                            {this.props.t('NEW_USER_NAME_LASTNAME')}:
                    </Col>
                        <Col span={18}>
                            <Input onChange={this.changeLastName}></Input>
                        </Col>
                    </Row>
                    <Row gutter={[24, 12]}>
                        <Col span={6}>
                            {this.props.t('NEW_ADMIN_rank')}:
                    </Col>
                        <Col span={18}>
                            <Input onChange={this.changerank}></Input>
                        </Col>
                    </Row>
                    <Row gutter={[24, 12]}>
                        <Col span={6}>
                            {this.props.t('EDIT_ADMIN_E_MAIL')}:
                    </Col>
                        <Col span={18}>
                            <Input value={this.state.email} onChange={this.changeEmail}></Input>
                        </Col>
                    </Row>
                    <Row gutter={[24, 12]}>
                        <Col span={6}>
                            {this.props.t('NEW_USER_WORK_START_DATE')}:
                    </Col>
                        <Col span={18}>
                            <DatePicker
                                value={moment(this.state.workStartDate * 1000)}
                                onChange={this.onChangeDate}
                            />
                        </Col>
                    </Row>
                    <Row gutter={[24, 12]}>
                        <Col span={6}>
                            {this.props.t('EDIT_ADMIN_NEW_PASSWORD')}:
                    </Col>
                        <Col span={18}>
                            <Input.Password
                                placeholder="Minnimum 8 karakter, kis- és nagybetű, szám"
                                onChange={this.analyzeNewPassword} />
                        </Col>
                    </Row>
                    <Row gutter={[24, 12]}>
                        <Col span={6}>
                            {this.props.t('EDIT_ADMIN_NEW_PASSWORD_AGAIN')}:
                    </Col>
                        <Col span={18}>
                            <Input.Password placeholder="Új jelszó újra" onChange={this.handleChangeRepeatedPassword}></Input.Password>
                        </Col>
                    </Row>
                    <Row gutter={[24, 12]} justify="center">
                        <Button className="save-new-pharmacy-button" type="primary" onClick={this.formChecker}>{this.props.t('EDIT_ADMIN_SAVE_BUTTON')}</Button>
                    </Row>
                </Col>
            </Row>
        </React.Fragment >;
    }
}
const mapStateToProps = (state) => ({
    newUserSaveStatus: state.userReducer.newUserSaveStatus,
    addAdminOrTrainerStatus: state.userReducer.addAdminOrTrainerStatus,
    loggedInUser: state.loginReducer.user,
    userCode: state.userReducer.userCode,
    addUserStatus: state.userReducer.addUserStatus,
    code: state.userReducer.code,
});
const NewTrainer = withTranslation()(connect(mapStateToProps, mapDispatchToProps)(ConnectedNewTrainer));
export default NewTrainer;