import { Table, Tabs } from "antd";
import React, { Component } from "react";
import { withTranslation } from "react-i18next";
import { connect } from "react-redux";
import { getAllUserCourseData } from "../../actions/user";
import ExamCourseData from "./exam-course-data";
import SimpleCourseData from "./simple-course-data";
const { TabPane } = Tabs;

const mapDispatchToProps = (dispatch) => {
  return {
    getAllUserCourseData: (userId) => dispatch(getAllUserCourseData(userId)),
  };
};

class ConnectedUserCourse extends Component {
  state = {
    exams: [],
    courses: [],
    columns: [
      {
        title: this.props.t("USER_LIST_TABLE_NAME"),
        dataIndex: "name",
        key: "name",
        sorter: (a, b) => a.name.localeCompare(b.name),
      },
      {
        title: this.props.t("USER_LIST_TABLE_FINISHED"),
        dataIndex: "isFinished",
        key: "isFinished",
        sorter: (a, b) => a.isFinished.localeCompare(b.isFinished),
        render: (isFinished) => {
            return <div>{isFinished ? "Befejezett" : "Folyamatban"}</div>;
        },
      },
      {
        title: this.props.t("COURSE_TABLE_CREATED"),
        dataIndex: "created",
        key: "created",
        render: (created) => {
          const actualCreated = new Date(created);
          return <div>{actualCreated.toLocaleDateString()}</div>;
        },
      },
      {
        title: this.props.t("COURSE_TABLE_EDITED"),
        dataIndex: "modified",
        key: "modified",
        render: (modified) => {
          const actualModified = new Date(modified);
          return <div>{actualModified.toLocaleDateString()}</div>;
        },
      },
    ],
  };
  componentDidMount = async () => {
    await this.props.getAllUserCourseData(this.props.userId);
    if (this.props.userCourseStatus === "loaded") {
      let examData = [];
      let courseData = [];
      for (let index = 0; index < this.props.userCourses.length; index++) {
        const element = this.props.userCourses[index];
        const data = {};
        data.id = element.course.id;
        data.name = element.course.name;
        data.created = element.created;
        data.modified = element.modified;
        data.isFinished = element.isFinished;
        data.expandabledata = {
          description: element.course.description,
          examSuccessful: element.examSuccessful,
          timeSpent: element.timeSpent,
          examRating: element.examRating,

          isActive: element.isActive,
        };
        if (element.courseTypeId === 2) {
          examData = [...examData, data];
        }
        if (element.courseTypeId === 1) {
          courseData = [...courseData, data];
        }
      }
      this.setState({ exams: examData, courses: courseData });
    }
  };
  render() {
    return (
      <div>
        <Tabs
          defaultActiveKey="1"
          tabPosition="left"
          // onChange={this.callback}
        >
          <TabPane tab={this.props.t("USER_COURSE_TAB_1")} key="1">
            <Table
              columns={this.state.columns}
              key={this.state.courses.id}
              expandable={{
                expandedRowRender: (record) => (
                  <SimpleCourseData data={record.expandabledata} />
                ),
                rowExpandable: (record) => record.name !== "Not Expandable",
              }}
              dataSource={this.state.courses}
            />
          </TabPane>
          <TabPane tab={this.props.t("USER_COURSE_TAB_2")} key="2">
            <Table
              columns={this.state.columns}
              key={this.state.courses.id}
              expandable={{
                expandedRowRender: (record) => (
                  <ExamCourseData data={record.expandabledata} />
                ),
                rowExpandable: (record) => record.name !== "Not Expandable",
              }}
              dataSource={this.state.exams}
            />
          </TabPane>
        </Tabs>
      </div>
    );
  }
}
const mapStateToProps = (state) => ({
  userCourses: state.userReducer.userCourses,
  userCourseStatus: state.userReducer.userCourseStatus,
});
const UserCourse = withTranslation()(
  connect(mapStateToProps, mapDispatchToProps)(ConnectedUserCourse)
);
export default UserCourse;
