import React, { Component } from 'react';
import { connect } from 'react-redux';
import { Row, Input, Col, Button, notification } from 'antd';
import { updateLoggedInUserProfile } from '../../actions/user';
import { withTranslation } from 'react-i18next';
const mapDispatchToProps = (dispatch) => {
    return {
        updateLoggedInUserProfile: (userProfile) => dispatch(updateLoggedInUserProfile(userProfile)),
    };
};

const strongRegex = new RegExp("^(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.{8,})");
// const mediumRegex = new RegExp("^(((?=.*[a-z])(?=.*[A-Z]))|((?=.*[a-z])(?=.*[0-9]))|((?=.*[A-Z])(?=.*[0-9])))(?=.{6,})");


class ConnectedUser extends Component {
  state = {
    newPasswordIsStrong: false,
    newPassword: "",
    repeatedNewPassword: "",
    oldPassWord: "",
    firstName: "",
    lastName: "",
    formValid: false,
  };

  componentDidMount = () => {
    this.setState({
      firstName: this.props.user.firstName,
      lastName: this.props.user.lastName,
    });
  };

  analyzeNewPassword = (event) => {
    const actualValue = event.target.value;
    this.setState({ newPassword: actualValue });
    if (strongRegex.test(actualValue)) {
      this.setState({ newPasswordIsStrong: true });
    } else {
      this.setState({ newPasswordIsStrong: false });
    }
  };

  handleChangeRepeatedPassword = (event) => {
    const actualValue = event.target.value;
    this.setState({ repeatedNewPassword: actualValue });
  };

  handleChangeFirstName = (event) => {
    const actualValue = event.target.value;
    this.setState({ firstName: actualValue });
  };

  handleChangeLastName = (event) => {
    const actualValue = event.target.value;
    this.setState({ lastName: actualValue });
  };
  handleChangeOldPassWord = (event) => {
    const actualValue = event.target.value;
    this.setState({ oldPassWord: actualValue });
  };

  formChecker = async () => {
    if (!this.state.firstName || this.state.firstName.trim() === "") {
      notification["error"]({
        message: this.props.t("USER_SAVE_ERROR_NAME_ERROR_TITLE"),
        description: this.props.t("USER_SAVE_ERROR_NAME_ERROR_DESC"),
        onClick: () => {
        },
      });
    } else if (!this.state.lastName || this.state.lastName.trim() === "") {
      notification["error"]({
        message: this.props.t("USER_SAVE_ERROR_NAME_ERROR_TITLE"),
        description: this.props.t("USER_SAVE_ERROR_NAME_ERROR_DESC"),
        onClick: () => {
        },
      });
    } else if (this.state.newPasswordIsStrong !== true) {
      notification["error"]({
        message: this.props.t("USER_SAVE_ERROR_PASSWORD_1_ERROR_TITLE"),
        description: this.props.t("USER_SAVE_ERROR_PASSWORD_1_ERROR_DESC"),
        onClick: () => {
        },
      });
    } else if (this.state.newPassword !== this.state.repeatedNewPassword) {
      notification["error"]({
        message: this.props.t("USER_SAVE_ERROR_PASSWORD_2_ERROR_TITLE"),
        description: this.props.t("USER_SAVE_ERROR_PASSWORD_2_ERROR_DESC"),
        onClick: () => {
        },
      });
    } else {
      const saveObj = {
        id: this.props.user.id,
        firstName: this.state.firstName,
        lastName: this.state.lastName,
        email: this.props.user.email,
        oldPassWord: this.state.oldPassWord,
        newPassword: this.state.newPassword,
      };
      await this.props.updateLoggedInUserProfile(saveObj);
      if (
        this.props.modifyUserStatus &&
        this.props.modifyUserStatus === "saved"
      ) {
        notification["success"]({
          message: this.props.t("USER_SAVE_SUCCESS_TITLE"),
          description: this.props.t("USER_SAVE_SUCCESS_DESC"),
          onClick: () => {
          },
        });
      } else {
        notification["error"]({
          message: this.props.t("USER_SAVE_ERROR_TITLE"),
          description: this.props.t("USER_SAVE_ERROR_DESC"),
          onClick: () => {
          },
        });
      }
    }
  };

  render() {
    return (
      <React.Fragment>
        <Row gutter={[24, 12]}>
          <Col span={6}></Col>
          <Col span={10}>
            <Col span={24}>{this.props.t("USER_NAME_FIRST")}:</Col>
            <Col span={24}>
              <Input
                value={this.state.firstName}
                onChange={this.handleChangeFirstName}
              ></Input>
            </Col>
            <Col span={24}>{this.props.t("USER_NAME_LAST")}:</Col>
            <Col span={24}>
              <Input
                value={this.state.lastName}
                onChange={this.handleChangeLastName}
              ></Input>
            </Col>
            <Col span={24}>{this.props.t("USER_EMAIL")}:</Col>
            <Col span={24}>
              <Input
                disabled={true}
                defaultValue={this.props.user.email}
              ></Input>
            </Col>
            <Col span={24}>{this.props.t("USER_OLD_PASSWORD")}:</Col>
            <Col span={24}>
              <Input.Password
                onChange={this.handleChangeOldPassWord}
                placeholder="jelenlegi jelszó"
              ></Input.Password>
            </Col>
            <Col span={24}>{this.props.t("USER_NEW_PASSWORD_1")}:</Col>
            <Col span={24}>
              <Input.Password
                placeholder="Minnimum 8 karakter, kis- és nagybetű, szám"
                onChange={this.analyzeNewPassword}
              />
            </Col>
            <Col span={24}>{this.props.t("USER_NEW_PASSWORD_2")}:</Col>
            <Col span={24}>
              <Input.Password
                placeholder="Új jelszó újra"
                onChange={this.handleChangeRepeatedPassword}
              ></Input.Password>
            </Col>
            <Col
              span={24}
              style={{
                display: "flex",
                alignItems: "center",
                justifyContent: "center",
                paddingTop: "2em",
              }}
            >
              <Button
                type="primary"
                className="save-new-pharmacy-button"
                onClick={this.formChecker}
              >
                {this.props.t("US2ER_SAVE")}
              </Button>
            </Col>
          </Col>
          <Col span={6}></Col>
        </Row>
      </React.Fragment>
    );
  }
}
const mapStateToProps = (state) => ({
    user: state.loginReducer.user,
    modifyUserStatus: state.userReducer.modifyUserStatus
});
const User = withTranslation()(connect(mapStateToProps, mapDispatchToProps)(ConnectedUser));
export default User;