import { COURSE } from "../constants/action-types";

const initialState = {
  courses: [],
  course: {},
  message: {},
  pdfURL: {},
  pdfstatus: null,
  allPdfURL: {},
  allPdfstatus: null,
  status: null,
  isActiveStatus: null,
  baseSavingStatus: null,
  documentationSavingStatus: null,
  deleteStatus: null,
  code: null,
  documentationDPFStatus: null,
  documentationDPF: {},
  documentationStatus: null,
  documentation: {},
};

const courseReducer = (state = initialState, action) => {
    switch (action.type) {
      case COURSE.GET_ALL_COURSE_BY_USER_LOADING:
        return Object.assign({}, state, {
          courses: [],
          message: {},
          status: "loading",
          code: null,
        });
      case COURSE.GET_ALL_COURSE_BY_USER_LOADED:
        return Object.assign({}, state, {
          courses: action.payload,
          status: "loaded",
          message: {},
          code: null,
        });
      case COURSE.GET_ALL_COURSE_BY_USER_ERROR:
        return Object.assign({}, state, {
          courses: [],
          status: "error",
          message: action.payload.message,
          code: action.payload.code,
        });
      case COURSE.COURSE_DELETING:
        return Object.assign({}, state, {
          message: {},
          deleteStatus: "deleting",
          code: null,
        });
      case COURSE.COURSE_DELETED:
        return Object.assign({}, state, {
          deleteStatus: "deleted",
          message: {},
          code: null,
        });
      case COURSE.COURSE_DELETE_ERROR:
        return Object.assign({}, state, {
          deleteStatus: "error",
          message: action.payload.message,
          code: action.payload.code,
        });
      case COURSE.GET_COURSE_BY_ID_LOADING:
        return Object.assign({}, state, {
          course: {},
          message: {},
          status: "loading",
          code: null,
        });
      case COURSE.GET_COURSE_BY_ID_LOADED:
        return Object.assign({}, state, {
          course: action.payload,
          status: "loaded",
          message: {},
          code: null,
        });
      case COURSE.GET_COURSE_BY_ID_ERROR:
        return Object.assign({}, state, {
          course: {},
          status: "error",
          message: action.payload.message,
          code: action.payload.code,
        });
      case COURSE.GENERATE_PDF_LOADING:
        return Object.assign({}, state, {
          pdfURL: {},
          pdfstatus: "loading",
          message: {},
          code: null,
        });
      case COURSE.GENERATE_PDF_LOADED:
        return Object.assign({}, state, {
          pdfURL: action.payload,
          pdfstatus: "loaded",
          message: {},
          code: null,
        });
      case COURSE.GENERATE_PDF_ERROR:
        return Object.assign({}, state, {
          pdfURL: {},
          pdfstatus: "error",
          message: action.payload.message,
          code: action.payload.code,
        });
      case COURSE.GENERATE_ALL_PDF_LOADING:
        return Object.assign({}, state, {
          allPdfURL: {},
          allPdfstatus: "loading",
          message: {},
          code: null,
        });
      case COURSE.GENERATE_ALL_PDF_LOADED:
        return Object.assign({}, state, {
          allPdfURL: action.payload,
          allPdfstatus: "loaded",
          message: {},
          code: null,
        });
      case COURSE.GENERATE_ALL_PDF_ERROR:
        return Object.assign({}, state, {
          allPdfURL: {},
          allPdfstatus: "error",
          message: action.payload.message,
          code: action.payload.code,
        });
      case COURSE.IS_ACTIVE_LOADING:
        return Object.assign({}, state, {
          isActiveStatus: "loading",
          message: {},
          code: null,
        });
      case COURSE.IS_ACTIVE_LOADED:
        return Object.assign({}, state, {
          isActiveStatus: "loaded",
          message: {},
          code: null,
        });
      case COURSE.IS_ACTIVE_ERROR:
        return Object.assign({}, state, {
          isActiveStatus: "error",
          message: action.payload.message,
          code: action.payload.code,
        });
      case COURSE.BASE_SAVING:
        return Object.assign({}, state, {
          baseSavingStatus: "saving",
          message: {},
          code: null,
        });
      case COURSE.BASE_SAVED:
        return Object.assign({}, state, {
          baseSavingStatus: "saved",
          message: {},
          code: null,
        });
      case COURSE.BASE_SAVE_ERROR:
        return Object.assign({}, state, {
          baseSavingStatus: "error",
          message: action.payload.message,
          code: action.payload.code,
        });
      case COURSE.SET_DOCUMENTATION_SAVING:
        return Object.assign({}, state, {
          documentationSavingStatus: "saving",
          message: {},
          code: null,
        });
      case COURSE.SET_DOCUMENTATION_SAVED:
        return Object.assign({}, state, {
          documentationSavingStatus: "saved",
          message: {},
          code: null,
        });
      case COURSE.SET_DOCUMENTATION_ERROR:
        return Object.assign({}, state, {
          documentationSavingStatus: "error",
          message: action.payload.message,
          code: action.payload.code,
        });
      case COURSE.GET_DOCUMENTATION_LOADING:
        return Object.assign({}, state, {
          documentationDPFStatus: "loading",
          documentationDPF: {},
          message: {},
          code: null,
        });
      case COURSE.GET_DOCUMENTATION_LOADED:
        return Object.assign({}, state, {
          documentationDPFStatus: "loaded",
          documentationDPF: action.payload,
          message: {},
          code: null,
        });
      case COURSE.GET_DOCUMENTATION_ERROR:
        return Object.assign({}, state, {
          documentationDPFStatus: "error",
          documentationDPF: {},
          message: action.payload.message,
          code: action.payload.code,
        });
      case COURSE.GET_DOCUMENTATION_DATA_LOADING:
        return Object.assign({}, state, {
          documentationStatus: "loading",
          documentation: {},
          message: {},
          code: null,
        });
      case COURSE.GET_DOCUMENTATION_DATA_LOADED:
        return Object.assign({}, state, {
          documentationStatus: "loaded",
          documentation: action.payload,
          message: {},
          code: null,
        });
      case COURSE.GET_DOCUMENTATION_DATA_ERROR:
        return Object.assign({}, state, {
          documentationStatus: "error",
          documentation: {},
          message: action.payload.message,
          code: action.payload.code,
        });
      case COURSE.GET_STATISTICS_LOADED:
        return Object.assign({}, state, {
          statisticsStatus: "loaded",
          statistics: action.payload,
          message: {},
          code: null,
        });
      case COURSE.GET_STATISTICS_LOADING:
        return Object.assign({}, state, {
          statisticsStatus: "loading",
          statistics: {},
          message: {},
          code: null,
        });
      case COURSE.GET_STATISTICS_ERROR:
        return Object.assign({}, state, {
          statisticsStatus: "error",
          statistics: {},
          message: action.payload.message,
          code: action.payload.code,
        });
      default:
        return state;
    }
};

export default courseReducer;
