import { USER, REGISTRATION } from "../constants/action-types";

const initialState = {
  users: [],
  usersStatus: null,

  newUserSaveStatus: null,
  user: undefined,
  userStatus: null,
  locationAdmins: [],
  locationAdminsStatus: null,
  admins: [],
  adminsStatus: null,
  natureTrails: [],
  status: null,
  message: {},
  code: null,
  deleteStatus: null,
  modifyUserStatus: null,
  modifyAdminStatus: null,
  activateDeactivateStatus: null,
  players: [],
  playersStatus: null,
  trainers: [],
  trainersStatus: null,
  addUserStatus: null,
  addAdminOrTrainerStatus: null,
  courseUsers: [],
  userCode: 0,
  userCourses: [],
  userCourseStatus: null,
};

const userReducer = (state = initialState, action) => {
  switch (action.type) {
    case USER.USER_NATURETRAIL_LOADING:
      return Object.assign({}, state, {
        natureTrails: [],
        message: {},
        status: "loading",
        code: null,
      });
    case USER.GET_ALL_USER_LOADING:
      return Object.assign({}, state, {
        users: [],
        message: {},
        usersStatus: "loading",
        code: null,
      });
    case USER.GET_ALL_USER_LOADED:
      return Object.assign({}, state, {
        users: action.payload,
        usersStatus: "loaded",
        message: {},
        code: null,
      });
    case USER.GET_ALL_USER_ERROR:
      return Object.assign({}, state, {
        users: [],
        usersStatus: "error",
        message: action.payload.message,
        code: action.payload.code,
      });
    case USER.GET_ALL_LOCATION_ADMIN_LOADING:
      return Object.assign({}, state, {
        locationAdmins: [],
        message: {},
        locationAdminsStatus: "loading",
        code: null,
      });
    case USER.GET_ALL_LOCATION_ADMIN_LOADED:
      return Object.assign({}, state, {
        locationAdmins: action.payload,
        locationAdminsStatus: "loaded",
        message: {},
        code: null,
      });
    case USER.GET_ALL_LOCATION_ADMIN_ERROR:
      return Object.assign({}, state, {
        locationAdmins: [],
        locationAdminsStatus: "error",
        message: action.payload.message,
        code: action.payload.code,
      });
    case USER.GET_ALL_ADMIN_LOADING:
      return Object.assign({}, state, {
        admins: [],
        adminsStatus: "loading",
        message: {},
        code: null,
      });
    case USER.GET_ALL_ADMIN_LOADED:
      return Object.assign({}, state, {
        admins: action.payload,
        adminsStatus: "loaded",
        message: {},
        code: null,
      });
    case USER.GET_ALL_ADMIN_ERROR:
      return Object.assign({}, state, {
        admins: [],
        adminsStatus: "error",
        message: action.payload.message,
        code: action.payload.code,
      });
    case USER.USER_DATA_LOADING:
      return Object.assign({}, state, {
        user: {},
        message: {},
        userStatus: "loading",
        code: null,
      });
    case USER.USER_DATA_LOADED:
      return Object.assign({}, state, {
        user: action.payload,
        userStatus: "loaded",
        message: {},
        code: null,
      });
    case USER.USER_DATA_ERROR:
      return Object.assign({}, state, {
        user: undefined,
        userStatus: "error",
        message: action.payload.message,
        code: action.payload.code,
      });
    case USER.USER_DELETE_SENDING:
      return Object.assign({}, state, {
        message: {},
        deleteStatus: "sending",
        code: null,
      });
    case USER.USER_DELETE_SENDED:
      return Object.assign({}, state, {
        message: {},
        deleteStatus: "sended",
        code: null,
      });
    case USER.USER_DELETE_ERROR:
      return Object.assign({}, state, {
        deleteStatus: "error",
        message: action.payload.message,
        code: action.payload.code,
      });
    case USER.SAVE_LOCATION_ADMIN_START:
      return Object.assign({}, state, {
        locationAdminsStatus: "",
        message: {},
        code: null,
      });
    case USER.SAVE_LOCATION_ADMIN_SUCCESS:
      return Object.assign({}, state, {
        locationAdminsStatus: "saved",
        message: {},
        code: null,
      });
    case USER.SAVE_LOCATION_ADMIN_ERROR:
      return Object.assign({}, state, {
        locationAdminsStatus: "error",
        message: action.payload.message,
        code: action.payload.code,
      });
    case USER.SAVE_ADMIN_START:
      return Object.assign({}, state, {
        adminsStatus: "",
        message: {},
        code: null,
      });
    case USER.SAVE_ADMIN_SUCCESS:
      return Object.assign({}, state, {
        adminsStatus: "saved",
        message: {},
        code: null,
      });
    case USER.SAVE_ADMIN_ERROR:
      return Object.assign({}, state, {
        adminsStatus: "error",
        message: action.payload.message,
        code: action.payload.code,
      });
    case REGISTRATION.REGISTRATION_LOADING:
      return Object.assign({}, state, {
        newUserSaveStatus: "saving",
        message: {},
        code: null,
      });
    case REGISTRATION.REGISTRATION_LOADED:
      return Object.assign({}, state, {
        newUserSaveStatus: "saved",
        message: {},
        code: null,
      });

    case USER.DELETE_USERS_SENDING:
      return Object.assign({}, state, {
        usersDeleteStatus: "deleting",
        message: {},
        code: null,
      });
    case USER.DELETE_USERS_SENDED:
      return Object.assign({}, state, {
        usersDeleteStatus: "deleted",
        message: {},
        code: null,
      });
    case USER.DELETE_USERS_ERROR:
      return Object.assign({}, state, {
        usersDeleteStatus: "error",
        message: action.payload.message,
        code: action.payload.code,
      });
    case USER.GET_ALL_USER_WITHOUT_ADMIN_LOADING:
      return Object.assign({}, state, {
        userList: [],
        userListStatus: "loading",
        message: {},
        code: null,
      });
    case USER.GET_ALL_USER_WITHOUT_ADMIN_LOADED:
      return Object.assign({}, state, {
        userList: action.payload,
        userListStatus: "loaded",
        message: {},
        code: null,
      });
    case USER.GET_ALL_USER_WITHOUT_ADMIN_ERROR:
      return Object.assign({}, state, {
        userList: [],
        userListStatus: "error",
        message: action.payload,
        code: action.payload,
      });
    case USER.GET_ALL_PLAYER_LOADING:
      return Object.assign({}, state, {
        players: [],
        playersStatus: "loading",
        message: {},
        code: null,
      });
    case USER.GET_ALL_PLAYER_LOADED:
      return Object.assign({}, state, {
        players: action.payload,
        playersStatus: "loaded",
        message: {},
        code: null,
      });
    case USER.GET_ALL_PLAYER_ERROR:
      return Object.assign({}, state, {
        players: [],
        playersStatus: "error",
        message: action.payload,
        code: action.payload,
      });
    case USER.GET_ALL_MAINTAINER_LOADING:
      return Object.assign({}, state, {
        trainers: [],
        trainersStatus: "loading",
        message: {},
        code: null,
      });
    case USER.GET_ALL_MAINTAINER_LOADED:
      return Object.assign({}, state, {
        trainers: action.payload,
        trainersStatus: "loaded",
        message: {},
        code: null,
      });
    case USER.GET_ALL_MAINTAINER_ERROR:
      return Object.assign({}, state, {
        trainers: [],
        trainersStatus: "error",
        message: action.payload,
        code: action.payload,
      });
    case USER.MODIFY_USER_SENDING:
      return Object.assign({}, state, {
        user: [],
        modifyUserStatus: "sending",
        message: {},
        code: null,
      });
    case USER.MODIFY_USER_SENDED:
      return Object.assign({}, state, {
        user: action.payload,
        modifyUserStatus: "sended",
        message: {},
        code: null,
      });
    case USER.MODIFY_USER_ERROR:
      return Object.assign({}, state, {
        user: [],
        modifyUserStatus: "error",
        message: action.payload,
        code: action.payload,
      });
    case USER.MODIFY_ADMIN_SENDING:
      return Object.assign({}, state, {
        user: [],
        modifyAdminStatus: "sending",
        message: {},
        code: null,
      });
    case USER.MODIFY_ADMIN_SENDED:
      return Object.assign({}, state, {
        user: action.payload,
        modifyAdminStatus: "sended",
        message: {},
        code: null,
      });
    case USER.MODIFY_ADMIN_ERROR:
      return Object.assign({}, state, {
        user: [],
        modifyAdminStatus: "error",
        message: action.payload,
        code: action.payload,
      });
    case USER.UPDATE_LOGGED_IN_USER_LOADING:
      return Object.assign({}, state, {
        user: [],
        modifyUserStatus: "saving",
        message: {},
        code: null,
      });
    case USER.UPDATE_LOGGED_IN_USER_LOADED:
      return Object.assign({}, state, {
        user: action.payload,
        modifyUserStatus: "saved",
        message: {},
        code: null,
      });
    case USER.UPDATE_LOGGED_IN_USER_ERROR:
      return Object.assign({}, state, {
        user: [],
        modifyUserStatus: "error",
        message: action.payload,
        code: action.payload,
      });
    case USER.ACTIVE_OR_DEACTIVE_LOADING:
      return Object.assign({}, state, {
        activateDeactivateStatus: "loading",
        message: {},
        code: null,
      });
    case USER.ACTIVE_OR_DEACTIVE_LOADED:
      return Object.assign({}, state, {
        activateDeactivateStatus: "loaded",
        message: {},
        code: null,
      });
    case USER.ACTIVE_OR_DEACTIVE_ERROR:
      return Object.assign({}, state, {
        activateDeactivateStatus: "error",
        message: action.payload,
        code: action.payload,
      });
    case USER.GET_ALL_COURSE_USERS_LOADING:
      return Object.assign({}, state, {
        courseUsers: [],
        status: "loading",
        message: {},
        code: null,
      });
    case USER.GET_ALL_COURSE_USERS_LOADED:
      return Object.assign({}, state, {
        courseUsers: action.payload.users,
        status: "loaded",
        message: {},
        code: null,
      });
    case USER.GET_ALL_COURSE_USERS_ERROR:
      return Object.assign({}, state, {
        courseUsers: [],
        status: "loaded",
        message: action.payload,
        code: action.payload,
      });
    case USER.GET_ALL_COURSE_USERS_EXAM_LOADING:
      return Object.assign({}, state, {
        courseExamUsers: [],
        status: "loading",
        message: {},
        code: null,
      });
    case USER.GET_ALL_COURSE_USERS_EXAM_LOADED:
      return Object.assign({}, state, {
        courseExamUsers: action.payload.users,
        status: "loaded",
        message: {},
        code: null,
      });
    case USER.GET_ALL_COURSE_USERS_EXAM_ERROR:
      return Object.assign({}, state, {
        courseExamUsers: [],
        status: "loaded",
        message: action.payload,
        code: action.payload,
      });
    case USER.GET_NEW_USER_CODE_LOADING:
      return Object.assign({}, state, {
        userCode: 0,
        status: "loading",
        message: {},
        code: null,
      });
    case USER.GET_NEW_USER_CODE_LOADED:
      return Object.assign({}, state, {
        userCode: action.payload,
        status: "loaded",
        message: {},
        code: null,
      });
    case USER.GET_NEW_USER_CODE_ERROR:
      return Object.assign({}, state, {
        userCode: 0,
        status: "loaded",
        message: action.payload,
        code: action.payload,
      });
    case USER.ADD_USER_SENDING:
      return Object.assign({}, state, {
        addUserStatus: "sending",
        message: {},
        code: null,
      });
    case USER.ADD_USER_SENDED:
      return Object.assign({}, state, {
        addUserStatus: "sended",
        message: {},
        code: null,
      });
    case USER.ADD_USER_ERROR:
      return Object.assign({}, state, {
        addUserStatus: "error",
        message: {},
        code: action.payload.code,
      });
    case USER.ADD_ADMIN_OR_TRAINER_SENDING:
      return Object.assign({}, state, {
        addAdminOrTrainerStatus: "sending",
        message: {},
        code: null,
      });
    case USER.ADD_ADMIN_OR_TRAINER_SENDED:
      return Object.assign({}, state, {
        addAdminOrTrainerStatus: "sended",
        message: {},
        code: null,
      });
    case USER.ADD_ADMIN_OR_TRAINER_ERROR:
      return Object.assign({}, state, {
        addAdminOrTrainerStatus: "error",
        message: {},
        code: action.payload.code,
      });
    case USER.USER_COURSE_LOADING:
      return Object.assign({}, state, {
        userCourseStatus: "loading",
        userCourses: [],
        message: {},
        code: null,
      });
    case USER.USER_COURSE_LOADED:
      return Object.assign({}, state, {
        userCourseStatus: "loaded",
        userCourses: action.payload.user,
        message: {},
        code: null,
      });
    case USER.USER_COURSE_ERROR:
      return Object.assign({}, state, {
        userCourseStatus: "error",
        userCourses: [],
        message: action.payload.message,
        code: action.payload.code,
      });
    default:
      return state;
  }
};

export default userReducer;
