import { createStore, combineReducers, applyMiddleware } from "redux";
import { composeWithDevTools } from "redux-devtools-extension";
import thunk from "redux-thunk";
import { persistStore, persistReducer } from "redux-persist";
import storage from "redux-persist/lib/storage/session";
import loginReducer from "../reducers/login";
import registrationReducer from "../reducers/registration";
import userReducer from "../reducers/user";
import courseReducer from "../reducers/course";
import fileManagerReducer from "../reducers/file-manager";
import languageReducer from "../reducers/language";
import unityReducer from "../reducers/unity";
import filterReducer from "../reducers/filter";
import tabHelperReducer from "../reducers/tab-helper";
import statisticsReducer from "../reducers/statistics";

const persistConfig = {
  key: "root",
  storage: storage,
  blacklist: [
    "userReducer",
    "courseReducer",
    "fileManagerReducer",
    "languageReducer",
    "unityReducer",
    "filterReducer",
    "tabHelperReducer",
    "statisticsReducer"
  ],
};

const rootReducer = combineReducers({
  loginReducer,
  registrationReducer,
  userReducer,
  courseReducer,
  fileManagerReducer,
  languageReducer,
  unityReducer,
  filterReducer,
  tabHelperReducer,
  statisticsReducer
});

const persistedReducer = persistReducer(persistConfig, rootReducer);

export const store = createStore(
  persistedReducer,
  composeWithDevTools(applyMiddleware(thunk))
);

export const persistor = persistStore(store);
